@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod
 
 from evalml.tuners import SKOptTuner
-from evalml.utils import get_random_state
+from evalml.utils import get_random_seed
 
 
 class AutoMLAlgorithmException(Exception):
@@ -25,9 +25,9 @@ class AutoMLAlgorithm(ABC):
             allowed_pipelines (list(class)): A list of PipelineBase subclasses indicating the pipelines allowed in the search. The default of None indicates all pipelines for this problem type are allowed.
             max_iterations (int): The maximum number of iterations to be evaluated.
             tuner_class (class): A subclass of Tuner, to be used to find parameters for each pipeline. The default of None indicates the SKOptTuner will be used.
-            random_state (int, np.random.RandomState): The random seed/state. Defaults to 0.
+            random_state (int): Seed for the random number generator. Defaults to 0.
         """
-        self.random_state = get_random_state(random_state)
+        self.random_state = get_random_seed(random_state)
         self.allowed_pipelines = allowed_pipelines or []
         self.max_iterations = max_iterations
         self._tuner_class = tuner_class or SKOptTuner
