@@ -31,7 +31,6 @@ from evalml.exceptions import (
 )
 from evalml.model_family import ModelFamily
 from evalml.objectives import (
-    get_all_objective_names,
     get_core_objectives,
     get_non_core_objectives,
     get_objective
@@ -42,14 +41,16 @@ from evalml.pipelines import (
     ModeBaselineBinaryPipeline,
     ModeBaselineMulticlassPipeline,
     PipelineBase,
+    TimeSeriesBaselineBinaryPipeline,
+    TimeSeriesBaselineMulticlassPipeline,
     TimeSeriesBaselineRegressionPipeline
 )
 from evalml.pipelines.components.utils import get_estimators
-from evalml.pipelines.utils import make_pipeline
+from evalml.pipelines.utils import get_generated_pipeline_class, make_pipeline
 from evalml.preprocessing import split_data
-from evalml.problem_types import ProblemTypes, handle_problem_types
+from evalml.problem_types import ProblemTypes, handle_problem_types, is_binary
 from evalml.tuners import SKOptTuner
-from evalml.utils import convert_to_seconds, get_random_seed, get_random_state
+from evalml.utils import convert_to_seconds, get_random_seed
 from evalml.utils.gen_utils import (
     _convert_to_woodwork_structure,
     _convert_woodwork_types_wrapper
@@ -91,12 +92,12 @@ class AutoMLSearch:
                  random_state=0,
                  n_jobs=-1,
                  tuner_class=None,
-                 verbose=True,
                  optimize_thresholds=False,
                  ensembling=False,
                  max_batches=None,
                  problem_configuration=None,
                  train_best_pipeline=True,
+                 pipeline_parameters=None,
                  _pipelines_per_batch=5):
         """Automated pipeline search
 
@@ -145,7 +146,7 @@ class AutoMLSearch:
                 Callback function takes three positional parameters: The pipeline class, the pipeline parameters, and the AutoMLSearch object.
 
             add_result_callback (callable): Function called after each pipeline training iteration.
-                Callback function takes three positional parameters:: A dictionary containing the training results for the new pipeline, an untrained_pipeline containing the parameters used during training, and the AutoMLSearch object.
+                Callback function takes three positional parameters: A dictionary containing the training results for the new pipeline, an untrained_pipeline containing the parameters used during training, and the AutoMLSearch object.
 
             error_callback (callable): Function called when `search()` errors and raises an Exception.
                 Callback function takes three positional parameters: the Exception raised, the traceback, and the AutoMLSearch object.
@@ -155,13 +156,11 @@ class AutoMLSearch:
             additional_objectives (list): Custom set of objectives to score on.
                 Will override default objectives for problem type if not empty.
 
-            random_state (int, np.random.RandomState): The random seed/state. Defaults to 0.
+            random_state (int): Seed for the random number generator. Defaults to 0.
 
             n_jobs (int or None): Non-negative integer describing level of parallelism used for pipelines.
                 None and 1 are equivalent. If set to -1, all CPUs are used. For n_jobs below -1, (n_cpus + 1 + n_jobs) are used.
 
-            verbose (boolean): If True, turn verbosity on. Defaults to True.
-
             ensembling (boolean): If True, runs ensembling in a separate batch after every allowed pipeline class has been iterated over.
                 If the number of unique pipelines to search over per batch is one, ensembling will not run. Defaults to False.
 
@@ -190,7 +189,6 @@ class AutoMLSearch:
         self.add_result_callback = add_result_callback
         self.error_callback = error_callback or log_error_callback
         self.data_splitter = data_splitter
-        self.verbose = verbose
         self.optimize_thresholds = optimize_thresholds
         self.ensembling = ensembling
         if objective == 'auto':
@@ -211,6 +209,7 @@ class AutoMLSearch:
             additional_objectives = [get_objective(o) for o in additional_objectives]
         additional_objectives = [self._validate_objective(obj) for obj in additional_objectives]
         self.additional_objectives = additional_objectives
+        self.objective_name_to_class = {o.name: o for o in [self.objective] + self.additional_objectives}
 
         if not isinstance(max_time, (int, float, str, type(None))):
             raise TypeError(f"Parameter max_time must be a float, int, string or None. Received {type(max_time)} with value {str(max_time)}..")
@@ -241,8 +240,7 @@ class AutoMLSearch:
             'search_order': [],
             'errors': []
         }
-        self.random_state = get_random_state(random_state)
-        self.random_seed = get_random_seed(self.random_state)
+        self.random_state = get_random_seed(random_state)
         self.n_jobs = n_jobs
 
         self.plot = None
@@ -264,14 +262,16 @@ class AutoMLSearch:
         self.problem_configuration = self._validate_problem_configuration(problem_configuration)
         self._train_best_pipeline = train_best_pipeline
         self._best_pipeline = None
+        self._searched = False
 
         # make everything ww objects
         self.X_train = _convert_to_woodwork_structure(X_train)
         self.y_train = _convert_to_woodwork_structure(y_train)
 
         default_data_splitter = make_data_splitter(self.X_train, self.y_train, self.problem_type, self.problem_configuration,
-                                                   n_splits=3, shuffle=True, random_state=self.random_seed)
+                                                   n_splits=3, shuffle=True, random_state=self.random_state)
         self.data_splitter = self.data_splitter or default_data_splitter
+        self.pipeline_parameters = pipeline_parameters if pipeline_parameters is not None else {}
 
     def _validate_objective(self, objective):
         non_core_objectives = get_non_core_objectives()
@@ -316,7 +316,6 @@ class AutoMLSearch:
             f"Additional Objectives: {_print_list(self.additional_objectives or [])}\n"
             f"Random State: {self.random_state}\n"
             f"n_jobs: {self.n_jobs}\n"
-            f"Verbose: {self.verbose}\n"
             f"Optimize Thresholds: {self.optimize_thresholds}\n"
         )
 
@@ -351,7 +350,7 @@ class AutoMLSearch:
             return AutoMLDataChecks(data_checks)
         elif isinstance(data_checks, str):
             if data_checks == "auto":
-                return DefaultDataChecks(problem_type=self.problem_type)
+                return DefaultDataChecks(problem_type=self.problem_type, objective=self.objective, n_splits=self.data_splitter.get_n_splits())
             elif data_checks == "disabled":
                 return EmptyDataChecks()
             else:
@@ -403,6 +402,10 @@ class AutoMLSearch:
             show_iteration_plot (boolean, True): Shows an iteration vs. score plot in Jupyter notebook.
                 Disabled by default in non-Jupyter enviroments.
         """
+        if self._searched:
+            logger.info("AutoMLSearch.search() has already been run and will not run again on the same instance. Re-initialize AutoMLSearch to search again.")
+            return
+
         # don't show iteration plot outside of a jupyter notebook
         if show_iteration_plot:
             try:
@@ -418,17 +421,17 @@ class AutoMLSearch:
         data_checks = self._validate_data_checks(data_checks)
         self._data_check_results = data_checks.validate(_convert_woodwork_types_wrapper(self.X_train.to_dataframe()),
                                                         _convert_woodwork_types_wrapper(self.y_train.to_series()))
-        for message in self._data_check_results["warnings"]:
-            logger.warning(message)
-        for message in self._data_check_results["errors"]:
-            logger.error(message)
+        for result in self._data_check_results["warnings"]:
+            logger.warning(result["message"])
+        for result in self._data_check_results["errors"]:
+            logger.error(result["message"])
         if self._data_check_results["errors"]:
             raise ValueError("Data checks raised some warnings and/or errors. Please see `self.data_check_results` for more information or pass data_checks='disabled' to search() to disable data checking.")
         if self.allowed_pipelines is None:
             logger.info("Generating pipelines to search over...")
             allowed_estimators = get_estimators(self.problem_type, self.allowed_model_families)
             logger.debug(f"allowed_estimators set to {[estimator.name for estimator in allowed_estimators]}")
-            self.allowed_pipelines = [make_pipeline(self.X_train, self.y_train, estimator, self.problem_type, text_columns=text_columns) for estimator in allowed_estimators]
+            self.allowed_pipelines = [make_pipeline(self.X_train, self.y_train, estimator, self.problem_type, custom_hyperparameters=self.pipeline_parameters, text_columns=text_columns) for estimator in allowed_estimators]
 
         if self.allowed_pipelines == []:
             raise ValueError("No allowed pipelines to search")
@@ -466,6 +469,10 @@ class AutoMLSearch:
 
         logger.debug(f"allowed_pipelines set to {[pipeline.name for pipeline in self.allowed_pipelines]}")
         logger.debug(f"allowed_model_families set to {self.allowed_model_families}")
+        if len(self.problem_configuration):
+            pipeline_params = {**{'pipeline': self.problem_configuration}, **self.pipeline_parameters}
+        else:
+            pipeline_params = self.pipeline_parameters
 
         self._automl_algorithm = IterativeAlgorithm(
             max_iterations=self.max_iterations,
@@ -477,7 +484,7 @@ class AutoMLSearch:
             number_features=self.X_train.shape[1],
             pipelines_per_batch=self._pipelines_per_batch,
             ensembling=run_ensembling,
-            pipeline_params=self.problem_configuration
+            pipeline_params=pipeline_params
         )
 
         log_title(logger, "Beginning pipeline search")
@@ -527,39 +534,44 @@ class AutoMLSearch:
 
         best_pipeline = self.rankings.iloc[0]
         best_pipeline_name = best_pipeline["pipeline_name"]
-        self._best_pipeline = self.get_pipeline(best_pipeline['id'])
-        if self._train_best_pipeline:
-            X_threshold_tuning = None
-            y_threshold_tuning = None
-            X_train, y_train = self.X_train, self.y_train
-            if self.optimize_thresholds and self.objective.is_defined_for_problem_type(ProblemTypes.BINARY) and self.objective.can_optimize_threshold:
-                X_train, X_threshold_tuning, y_train, y_threshold_tuning = split_data(X_train, y_train, self.problem_type,
-                                                                                      test_size=0.2,
-                                                                                      random_state=self.random_seed)
-            self._best_pipeline.fit(X_train, y_train)
-            self._best_pipeline = self._tune_binary_threshold(self._best_pipeline, X_threshold_tuning, y_threshold_tuning)
+        self._find_best_pipeline()
         logger.info(f"Best pipeline: {best_pipeline_name}")
         logger.info(f"Best pipeline {self.objective.name}: {best_pipeline['score']:3f}")
+        self._searched = True
+
+    def _find_best_pipeline(self):
+        """Finds the best pipeline in the rankings
+        If self._best_pipeline already exists, check to make sure it is different from the current best pipeline before training and thresholding"""
+        best_pipeline = self.rankings.iloc[0]
+        if not (self._best_pipeline and self._best_pipeline == self.get_pipeline(best_pipeline['id'])):
+            self._best_pipeline = self.get_pipeline(best_pipeline['id'])
+            if self._train_best_pipeline:
+                X_threshold_tuning = None
+                y_threshold_tuning = None
+                X_train, y_train = self.X_train, self.y_train
+                if self.optimize_thresholds and self.objective.is_defined_for_problem_type(ProblemTypes.BINARY) and self.objective.can_optimize_threshold and is_binary(self.problem_type):
+                    X_train, X_threshold_tuning, y_train, y_threshold_tuning = split_data(X_train, y_train, self.problem_type,
+                                                                                          test_size=0.2,
+                                                                                          random_state=self.random_state)
+                self._best_pipeline.fit(X_train, y_train)
+                self._best_pipeline = self._tune_binary_threshold(self._best_pipeline, X_threshold_tuning, y_threshold_tuning)
 
     def _tune_binary_threshold(self, pipeline, X_threshold_tuning, y_threshold_tuning):
         """Tunes the threshold of a binary pipeline to the X and y thresholding data
 
         Arguments:
             pipeline (Pipeline): Pipeline instance to threshold
-            X_threshold_tuning (ww DataTable): X data to tune pipeline to
-            y_threshold_tuning (ww DataColumn): Target data to tune pipeline to
+            X_threshold_tuning (ww.DataTable): X data to tune pipeline to
+            y_threshold_tuning (ww.DataColumn): Target data to tune pipeline to
 
         Returns:
             Trained pipeline instance
         """
-        if self.objective.is_defined_for_problem_type(ProblemTypes.BINARY):
+        if self.objective.is_defined_for_problem_type(ProblemTypes.BINARY) and is_binary(self.problem_type):
             pipeline.threshold = 0.5
             if X_threshold_tuning:
                 y_predict_proba = pipeline.predict_proba(X_threshold_tuning)
-                if isinstance(y_predict_proba, pd.DataFrame):
-                    y_predict_proba = y_predict_proba.iloc[:, 1]
-                else:
-                    y_predict_proba = y_predict_proba[:, 1]
+                y_predict_proba = y_predict_proba.iloc[:, 1]
                 pipeline.threshold = self.objective.optimize_threshold(y_predict_proba, y_threshold_tuning, X=X_threshold_tuning)
         return pipeline
 
@@ -621,9 +633,14 @@ class AutoMLSearch:
         elif self.problem_type == ProblemTypes.REGRESSION:
             baseline = MeanBaselineRegressionPipeline(parameters={})
         else:
+            pipeline_class = {ProblemTypes.TIME_SERIES_REGRESSION: TimeSeriesBaselineRegressionPipeline,
+                              ProblemTypes.TIME_SERIES_MULTICLASS: TimeSeriesBaselineMulticlassPipeline,
+                              ProblemTypes.TIME_SERIES_BINARY: TimeSeriesBaselineBinaryPipeline}[self.problem_type]
             gap = self.problem_configuration['gap']
             max_delay = self.problem_configuration['max_delay']
-            baseline = TimeSeriesBaselineRegressionPipeline(parameters={"pipeline": {"gap": gap, "max_delay": max_delay}})
+            baseline = pipeline_class(parameters={"pipeline": {"gap": gap, "max_delay": max_delay},
+                                                  "Time Series Baseline Estimator": {"gap": gap, "max_delay": max_delay}})
+
         pipelines = [baseline]
         scores = self._evaluate_pipelines(pipelines, baseline=True)
         if scores == []:
@@ -631,20 +648,23 @@ class AutoMLSearch:
         return False
 
     @staticmethod
-    def _get_mean_cv_scores_for_all_objectives(cv_data):
+    def _get_mean_cv_scores_for_all_objectives(cv_data, objective_name_to_class):
         scores = defaultdict(int)
-        objective_names = set([name.lower() for name in get_all_objective_names()])
         n_folds = len(cv_data)
         for fold_data in cv_data:
             for field, value in fold_data['all_objective_scores'].items():
-                if field.lower() in objective_names:
+                # The 'all_objective_scores' field contains scores for all objectives
+                # but also fields like "# Training" and "# Testing", so we want to exclude them since
+                # they are not scores
+                if field in objective_name_to_class:
                     scores[field] += value
-        return {objective_name: float(score) / n_folds for objective_name, score in scores.items()}
+        return {objective: float(score) / n_folds for objective, score in scores.items()}
 
     def _compute_cv_scores(self, pipeline):
         start = time.time()
         cv_data = []
         logger.info("\tStarting cross validation")
+
         X_pd = _convert_woodwork_types_wrapper(self.X_train.to_dataframe())
         y_pd = _convert_woodwork_types_wrapper(self.y_train.to_series())
         for i, (train, valid) in enumerate(self.data_splitter.split(X_pd, y_pd)):
@@ -668,11 +688,11 @@ class AutoMLSearch:
             try:
                 X_threshold_tuning = None
                 y_threshold_tuning = None
-                if self.optimize_thresholds and self.objective.is_defined_for_problem_type(ProblemTypes.BINARY) and self.objective.can_optimize_threshold:
+                if self.optimize_thresholds and self.objective.is_defined_for_problem_type(ProblemTypes.BINARY) and self.objective.can_optimize_threshold and is_binary(self.problem_type):
                     X_train, X_threshold_tuning, y_train, y_threshold_tuning = split_data(X_train, y_train, self.problem_type,
                                                                                           test_size=0.2,
-                                                                                          random_state=self.random_seed)
-                cv_pipeline = pipeline.clone(pipeline.random_state)
+                                                                                          random_state=self.random_state)
+                cv_pipeline = pipeline.clone()
                 logger.debug(f"\t\t\tFold {i}: starting training")
                 cv_pipeline.fit(X_train, y_train)
                 logger.debug(f"\t\t\tFold {i}: finished training")
@@ -716,9 +736,10 @@ class AutoMLSearch:
         cv_score = cv_scores.mean()
 
         percent_better_than_baseline = {}
-        mean_cv_all_objectives = self._get_mean_cv_scores_for_all_objectives(cv_data)
+        mean_cv_all_objectives = self._get_mean_cv_scores_for_all_objectives(cv_data, self.objective_name_to_class)
         for obj_name in mean_cv_all_objectives:
-            objective_class = get_objective(obj_name)
+            objective_class = self.objective_name_to_class[obj_name]
+
             # In the event add_to_rankings is called before search _baseline_cv_scores will be empty so we will return
             # nan for the base score.
             percent_better = objective_class.calculate_percent_difference(mean_cv_all_objectives[obj_name],
@@ -736,7 +757,6 @@ class AutoMLSearch:
         if high_variance_cv_check_results["warnings"]:
             logger.warning(high_variance_cv_check_results["warnings"][0]["message"])
             high_variance_cv = True
-
         self._results['pipeline_results'][pipeline_id] = {
             "id": pipeline_id,
             "pipeline_name": pipeline_name,
@@ -785,7 +805,7 @@ class AutoMLSearch:
                 parameters = pipeline.parameters
 
                 if baseline:
-                    self._baseline_cv_scores = self._get_mean_cv_scores_for_all_objectives(evaluation_results["cv_data"])
+                    self._baseline_cv_scores = self._get_mean_cv_scores_for_all_objectives(evaluation_results["cv_data"], self.objective_name_to_class)
 
                 logger.debug('Adding results for pipeline {}\nparameters {}\nevaluation_results {}'.format(pipeline.name, parameters, evaluation_results))
                 self._add_result(trained_pipeline=pipeline,
@@ -815,13 +835,12 @@ class AutoMLSearch:
 
         return current_batch_pipeline_scores
 
-    def get_pipeline(self, pipeline_id, random_state=0):
+    def get_pipeline(self, pipeline_id):
         """Given the ID of a pipeline training result, returns an untrained instance of the specified pipeline
         initialized with the parameters used to train that pipeline during automl search.
 
         Arguments:
             pipeline_id (int): pipeline to retrieve
-            random_state (int, np.random.RandomState): The random seed/state. Defaults to 0.
 
         Returns:
             PipelineBase: untrained pipeline instance associated with the provided ID
@@ -833,7 +852,11 @@ class AutoMLSearch:
         parameters = pipeline_results.get('parameters')
         if pipeline_class is None or parameters is None:
             raise PipelineNotFoundError("Pipeline class or parameters not found in automl results")
-        return pipeline_class(parameters, random_state=random_state)
+        pipeline = get_generated_pipeline_class(self.problem_type)
+        pipeline.custom_hyperparameters = pipeline_class.custom_hyperparameters
+        pipeline.custom_name = pipeline_class.name
+        pipeline.component_graph = pipeline_class.component_graph
+        return pipeline(parameters, random_state=self.random_state)
 
     def describe_pipeline(self, pipeline_id, return_dict=False):
         """Describe a pipeline
@@ -896,6 +919,7 @@ class AutoMLSearch:
             if pipeline.parameters == parameter:
                 return
         self._evaluate_pipelines(pipeline)
+        self._find_best_pipeline()
 
     @property
     def results(self):
@@ -906,12 +930,6 @@ class AutoMLSearch:
            """
         return copy.deepcopy(self._results)
 
-    @property
-    def has_searched(self):
-        """Returns `True` if search has been ran and `False` if not"""
-        searched = True if self._results['pipeline_results'] else False
-        return searched
-
     @property
     def rankings(self):
         """Returns a pandas.DataFrame with scoring results from the highest-scoring set of parameters used with each pipeline."""
@@ -926,7 +944,7 @@ class AutoMLSearch:
 
         full_rankings_cols = ["id", "pipeline_name", "score", "validation_score",
                               "percent_better_than_baseline", "high_variance_cv", "parameters"]
-        if not self.has_searched:
+        if not self._results['pipeline_results']:
             return pd.DataFrame(columns=full_rankings_cols)
 
         rankings_df = pd.DataFrame(self._results['pipeline_results'].values())
@@ -942,7 +960,7 @@ class AutoMLSearch:
         Returns:
             PipelineBase: A trained instance of the best pipeline and parameters found during automl search. If `train_best_pipeline` is set to False, returns an untrained pipeline instance.
         """
-        if not (self.has_searched and self._best_pipeline):
+        if not self._best_pipeline:
             raise PipelineNotFoundError("automl search must be run before selecting `best_pipeline`.")
 
         return self._best_pipeline
