@@ -25,16 +25,21 @@ class DefaultDataChecks(DataChecks):
     _DEFAULT_DATA_CHECK_CLASSES = [HighlyNullDataCheck, IDColumnsDataCheck,
                                    TargetLeakageDataCheck, InvalidTargetDataCheck, NoVarianceDataCheck]
 
-    def __init__(self, problem_type):
+    def __init__(self, problem_type, objective, n_splits=3):
         """
         A collection of basic data checks.
 
         Arguments:
             problem_type (str): The problem type that is being validated. Can be regression, binary, or multiclass.
+            objective (str or ObjectiveBase): Name or instance of the objective class.
+            n_splits (int): The number of splits as determined by the data splitter being used.
         """
         if handle_problem_types(problem_type) in [ProblemTypes.REGRESSION, ProblemTypes.TIME_SERIES_REGRESSION]:
             super().__init__(self._DEFAULT_DATA_CHECK_CLASSES,
-                             data_check_params={"InvalidTargetDataCheck": {"problem_type": problem_type}})
+                             data_check_params={"InvalidTargetDataCheck": {"problem_type": problem_type,
+                                                                           "objective": objective}})
         else:
             super().__init__(self._DEFAULT_DATA_CHECK_CLASSES + [ClassImbalanceDataCheck],
-                             data_check_params={"InvalidTargetDataCheck": {"problem_type": problem_type}})
+                             data_check_params={"InvalidTargetDataCheck": {"problem_type": problem_type,
+                                                                           "objective": objective},
+                                                "ClassImbalanceDataCheck": {"num_cv_folds": n_splits}})
