@@ -5,24 +5,17 @@ from evalml.data_checks import (
     DataCheckMessageCode,
     DataCheckWarning
 )
-from evalml.utils import get_random_state
 from evalml.utils.gen_utils import (
     _convert_to_woodwork_structure,
-    _convert_woodwork_types_wrapper,
-    numeric_dtypes
+    _convert_woodwork_types_wrapper
 )
 
 
 class OutliersDataCheck(DataCheck):
     """Checks if there are any outliers in input data by using IQR to determine score anomalies. Columns with score anomalies are considered to contain outliers."""
 
-    def __init__(self, random_state=0):
-        """Checks if there are any outliers in the input data.
-
-        Arguments:
-            random_state (int, np.random.RandomState): The random seed/state. Defaults to 0.
-        """
-        self.random_state = get_random_state(random_state)
+    def __init__(self):
+        """Checks if there are any outliers in the input data."""
 
     def validate(self, X, y=None):
         """Checks if there are any outliers in a dataframe by using IQR to determine column anomalies. Column with anomalies are considered to contain outliers.
@@ -54,9 +47,9 @@ class OutliersDataCheck(DataCheck):
         }
 
         X = _convert_to_woodwork_structure(X)
+        X = X.select('numeric')
         X = _convert_woodwork_types_wrapper(X.to_dataframe())
 
-        X = X.select_dtypes(include=numeric_dtypes)
         if len(X.columns) == 0:
             return messages
 
