@@ -1,7 +1,5 @@
 import os
 
-import woodwork as ww
-
 from evalml.preprocessing import load_data
 
 
@@ -25,8 +23,8 @@ def load_fraud(n_rows=None, verbose=True, return_pandas=False):
                      target="fraud",
                      n_rows=n_rows,
                      verbose=verbose)
+    X = X.set_types({"provider": "Categorical", "region": "Categorical"})
 
     if return_pandas:
-        return X, y
-
-    return ww.DataTable(X), ww.DataColumn(y)
+        return X.to_dataframe(), y.to_series()
+    return X, y
