@@ -9,5 +9,7 @@ from .exceptions import (
     PipelineNotYetFittedError,
     AutoMLSearchException,
     PipelineScoreError,
-    DataCheckInitError
+    DataCheckInitError,
+    EnsembleMissingPipelinesError,
+    NullsInColumnWarning
 )
