@@ -38,6 +38,11 @@ class AutoMLSearchException(Exception):
     pass
 
 
+class EnsembleMissingPipelinesError(Exception):
+    """An exception raised when an ensemble is missing `estimators` (list) as a parameter."""
+    pass
+
+
 class PipelineScoreError(Exception):
     """An exception raised when a pipeline errors while scoring any objective in a list of objectives.
 
@@ -65,3 +70,7 @@ class PipelineScoreError(Exception):
 
 class DataCheckInitError(Exception):
     """Exception raised when a data check can't initialize with the parameters given."""
+
+
+class NullsInColumnWarning(UserWarning):
+    """Warning thrown when there are null values in the column of interest"""
