@@ -1,20 +1,27 @@
 from .graphs import (
-    precision_recall_curve,
-    graph_precision_recall_curve,
-    roc_curve,
-    graph_roc_curve,
-    graph_confusion_matrix,
-    calculate_permutation_importance,
-    graph_permutation_importance,
-    confusion_matrix,
-    normalize_confusion_matrix,
     binary_objective_vs_threshold,
-    graph_binary_objective_vs_threshold,
-    partial_dependence,
-    graph_partial_dependence,
+    calculate_permutation_importance,
+    confusion_matrix,
+    get_linear_coefficients,
     get_prediction_vs_actual_data,
-    graph_prediction_vs_actual,
     get_prediction_vs_actual_over_time_data,
+    graph_binary_objective_vs_threshold,
+    graph_confusion_matrix,
+    graph_partial_dependence,
+    graph_permutation_importance,
+    graph_precision_recall_curve,
+    graph_prediction_vs_actual,
     graph_prediction_vs_actual_over_time,
+    graph_roc_curve,
+    graph_t_sne,
+    normalize_confusion_matrix,
+    partial_dependence,
+    precision_recall_curve,
+    roc_curve,
+    t_sne
+)
+from .prediction_explanations import (
+    explain_prediction,
+    explain_predictions,
+    explain_predictions_best_worst
 )
-from .prediction_explanations import explain_prediction, explain_predictions_best_worst, explain_predictions
