@@ -34,7 +34,7 @@ class FraudCost(BinaryClassificationObjective):
         """Determine if a transaction is fraud given predicted probabilities, threshold, and dataframe with transaction amount.
 
         Arguments:
-            ypred_proba (pd.Series): Predicted probablities
+            ypred_proba (ww.DataColumn, pd.Series): Predicted probablities
             threshold (float): Dollar threshold to determine if transaction is fraud
             X (ww.DataTable, pd.DataFrame): Data containing transaction amounts
 
@@ -51,8 +51,8 @@ class FraudCost(BinaryClassificationObjective):
         """Calculate amount lost to fraud per transaction given predictions, true values, and dataframe with transaction amount.
 
         Arguments:
-            y_predicted (pd.Series): Predicted fraud labels
-            y_true (pd.Series): True fraud labels
+            y_predicted (ww.DataColumn, pd.Series): Predicted fraud labels
+            y_true (ww.DataColumn, pd.Series): True fraud labels
             X (ww.DataTable, pd.DataFrame): Data with transaction amounts
 
         Returns:
