@@ -19,7 +19,10 @@ from .estimators import (
     BaselineRegressor,
     DecisionTreeClassifier,
     DecisionTreeRegressor,
-    TimeSeriesBaselineRegressor
+    TimeSeriesBaselineEstimator,
+    KNeighborsClassifier,
+    SVMClassifier,
+    SVMRegressor
 )
 from .transformers import (
     Transformer,
