@@ -6,10 +6,9 @@ import cloudpickle
 from evalml.exceptions import MethodPropertyNotFoundError
 from evalml.pipelines.components.component_base_meta import ComponentBaseMeta
 from evalml.utils import (
-    check_random_state_equality,
     classproperty,
     get_logger,
-    get_random_state,
+    get_random_seed,
     log_subtitle,
     safe_repr
 )
@@ -26,7 +25,7 @@ class ComponentBase(ABC, metaclass=ComponentBaseMeta):
     _default_parameters = None
 
     def __init__(self, parameters=None, component_obj=None, random_state=0, **kwargs):
-        self.random_state = get_random_state(random_state)
+        self.random_state = get_random_seed(random_state)
         self._component_obj = component_obj
         self._parameters = parameters or {}
         self._is_fitted = False
@@ -71,23 +70,20 @@ class ComponentBase(ABC, metaclass=ComponentBaseMeta):
 
         return cls._default_parameters
 
-    def clone(self, random_state=0):
-        """Constructs a new component with the same parameters
-
-        Arguments:
-            random_state (int, RandomState): the value to seed the random state with. Can also be a RandomState instance. Defaults to 0.
+    def clone(self):
+        """Constructs a new component with the same parameters and random state.
 
         Returns:
-            A new instance of this component with identical parameters
+            A new instance of this component with identical parameters and random state.
         """
-        return self.__class__(**self.parameters, random_state=random_state)
+        return self.__class__(**self.parameters, random_state=self.random_state)
 
     def fit(self, X, y=None):
         """Fits component to data
 
         Arguments:
-            X (ww.DataTable, pd.DataFrame or np.ndarray): The input training data of shape [n_samples, n_features]
-            y (ww.DataColumn, pd.Series, np.ndarray, optional): The target training data of length [n_samples]
+            X (list, ww.DataTable, pd.DataFrame or np.ndarray): The input training data of shape [n_samples, n_features]
+            y (list, ww.DataColumn, pd.Series, np.ndarray, optional): The target training data of length [n_samples]
 
         Returns:
             self
@@ -153,7 +149,7 @@ class ComponentBase(ABC, metaclass=ComponentBaseMeta):
     def __eq__(self, other):
         if not isinstance(other, self.__class__):
             return False
-        random_state_eq = check_random_state_equality(self.random_state, other.random_state)
+        random_state_eq = self.random_state == other.random_state
         if not random_state_eq:
             return False
         attributes_to_check = ['_parameters', '_is_fitted']
