@@ -7,7 +7,9 @@ from .classifiers import (LogisticRegressionClassifier,
                           ElasticNetClassifier,
                           ExtraTreesClassifier,
                           BaselineClassifier,
-                          DecisionTreeClassifier)
+                          DecisionTreeClassifier,
+                          KNeighborsClassifier,
+                          SVMClassifier)
 from .regressors import (LinearRegressor,
                          LightGBMRegressor,
                          RandomForestRegressor,
@@ -16,5 +18,6 @@ from .regressors import (LinearRegressor,
                          ElasticNetRegressor,
                          ExtraTreesRegressor,
                          BaselineRegressor,
-                         TimeSeriesBaselineRegressor,
-                         DecisionTreeRegressor)
+                         TimeSeriesBaselineEstimator,
+                         DecisionTreeRegressor,
+                         SVMRegressor)
