@@ -4,5 +4,5 @@ from .feature_selection import FeatureSelector, RFClassifierSelectFromModel, RFR
 from .imputers import PerColumnImputer, SimpleImputer, Imputer
 from .scalers import StandardScaler
 from .column_selectors import DropColumns, SelectColumns
-from .dimensionality_reduction import PCA
-from .preprocessing import DateTimeFeaturizer, DropNullColumns, LSA, TextFeaturizer, DelayedFeatureTransformer
+from .dimensionality_reduction import LinearDiscriminantAnalysis, PCA
+from .preprocessing import DateTimeFeaturizer, DropNullColumns, LSA, TextFeaturizer, DelayedFeatureTransformer, DFSTransformer
