@@ -18,10 +18,9 @@ from evalml.pipelines import ComponentGraph
 from evalml.pipelines.pipeline_base_meta import PipelineBaseMeta
 from evalml.utils import (
     _convert_to_woodwork_structure,
-    check_random_state_equality,
     classproperty,
     get_logger,
-    get_random_state,
+    get_random_seed,
     import_or_raise,
     jupyter_check,
     log_subtitle,
@@ -58,9 +57,9 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Arguments:
             parameters (dict): Dictionary with component names as keys and dictionary of that component's parameters as values.
                  An empty dictionary {} implies using all default values for component parameters.
-            random_state (int, np.random.RandomState): The random seed/state. Defaults to 0.
+            random_state (int): Seed for the random number generator. Defaults to 0.
         """
-        self.random_state = get_random_state(random_state)
+        self.random_state = get_random_seed(random_state)
         if isinstance(self.component_graph, list):  # Backwards compatibility
             self._component_graph = ComponentGraph().from_list(self.component_graph, random_state=self.random_state)
         else:
@@ -68,6 +67,8 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         self._component_graph.instantiate(parameters)
 
         self.input_feature_names = {}
+        self.input_target_name = None
+
         final_component = self._component_graph.get_last_component()
         self.estimator = final_component if isinstance(final_component, Estimator) else None
         self._estimator_name = self._component_graph.compute_order[-1] if self.estimator is not None else None
@@ -111,8 +112,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
 
     @classproperty
     def linearized_component_graph(cls):
-        """Returns a component graph in list form. Note: this is not guaranteed to be in proper component computation order
-        """
+        """Returns a component graph in list form. Note: this is not guaranteed to be in proper component computation order"""
         if isinstance(cls.component_graph, list):
             return cls.component_graph
         else:
@@ -130,13 +130,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
     def __getitem__(self, index):
         if isinstance(index, slice):
             raise NotImplementedError('Slicing pipelines is currently not supported.')
-        elif isinstance(index, int):
-            component_name = self.component_graph[index]
-            if not isinstance(component_name, str):
-                component_name = component_name.name
-            return self.get_component(component_name)
-        else:
-            return self.get_component(index)
+        return self._component_graph[index]
 
     def __setitem__(self, index, value):
         raise NotImplementedError('Setting pipeline components is not supported.')
@@ -180,20 +174,22 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         """Transforms the data by applying all pre-processing components.
 
         Arguments:
-            X (pd.DataFrame): Input data to the pipeline to transform.
+            X (ww.DataTable, pd.DataFrame): Input data to the pipeline to transform.
 
         Returns:
-            pd.DataFrame - New transformed features.
+            ww.DataTable: New transformed features.
         """
         X_t = self._component_graph.compute_final_component_features(X, y=y)
         return X_t
 
     def _compute_features_during_fit(self, X, y):
+        self.input_target_name = y.name
         X_t = self._component_graph.fit_features(X, y)
         self.input_feature_names = self._component_graph.input_feature_names
         return X_t
 
     def _fit(self, X, y):
+        self.input_target_name = y.name
         self._component_graph.fit(X, y)
         self.input_feature_names = self._component_graph.input_feature_names
 
@@ -218,10 +214,13 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             objective (Object or string): The objective to use to make predictions
 
         Returns:
-            pd.Series: Predicted values.
+            ww.DataColumn: Predicted values.
         """
         X = _convert_to_woodwork_structure(X)
-        return self._component_graph.predict(X)
+        predictions = self._component_graph.predict(X)
+        predictions_series = predictions.to_series()
+        predictions_series.name = self.input_target_name
+        return _convert_to_woodwork_structure(predictions_series)
 
     @abstractmethod
     def score(self, X, y, objectives):
@@ -251,6 +250,9 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             y_pred_proba (pd.Dataframe, pd.Series, None): The predicted probabilities for classification problems.
                 Will be a DataFrame for multiclass problems and Series otherwise. Will be None for regression problems.
             objectives (list): List of objectives to score.
+
+        Returns:
+            dict: Ordered dictionary with objectives and their scores.
         """
         scored_successfully = OrderedDict()
         exceptions = OrderedDict()
@@ -460,24 +462,21 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         with open(file_path, 'rb') as f:
             return cloudpickle.load(f)
 
-    def clone(self, random_state=0):
-        """Constructs a new pipeline with the same parameters and components.
-
-        Arguments:
-            random_state (int): the value to seed the random state with. Can also be a RandomState instance. Defaults to 0.
+    def clone(self):
+        """Constructs a new pipeline with the same components, parameters, and random state.
 
         Returns:
-            A new instance of this pipeline with identical parameters and components
+            A new instance of this pipeline with identical components, parameters, and random state.
         """
-        return self.__class__(self.parameters, random_state=random_state)
+        return self.__class__(self.parameters, random_state=self.random_state)
 
     def __eq__(self, other):
         if not isinstance(other, self.__class__):
             return False
-        random_state_eq = check_random_state_equality(self.random_state, other.random_state)
+        random_state_eq = self.random_state == other.random_state
         if not random_state_eq:
             return False
-        attributes_to_check = ['parameters', '_is_fitted', 'component_graph', 'input_feature_names']
+        attributes_to_check = ['parameters', '_is_fitted', 'component_graph', 'input_feature_names', 'input_target_name']
         for attribute in attributes_to_check:
             if getattr(self, attribute) != getattr(other, attribute):
                 return False
@@ -493,3 +492,9 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
 
         parameters_repr = ' '.join([f"'{component}':{{{repr_component(parameters)}}}," for component, parameters in self.parameters.items()])
         return f'{(type(self).__name__)}(parameters={{{parameters_repr}}})'
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        return next(self._component_graph)
