@@ -6,7 +6,6 @@ from evalml.problem_types import ProblemTypes
 from evalml.utils.gen_utils import (
     _convert_to_woodwork_structure,
     _convert_woodwork_types_wrapper,
-    _get_rows_without_nans,
     drop_rows_with_nans,
     pad_with_nans
 )
@@ -26,7 +25,7 @@ class TimeSeriesClassificationPipeline(ClassificationPipeline):
                  An empty dictionary {} implies using all default values for component parameters. Pipeline-level
                  parameters such as gap and max_delay must be specified with the "pipeline" key. For example:
                  Pipeline(parameters={"pipeline": {"max_delay": 4, "gap": 2}}).
-            random_state (int, np.random.RandomState): The random seed/state. Defaults to 0.
+            random_state (int): Seed for the random number generator. Defaults to 0.
         """
         if "pipeline" not in parameters:
             raise ValueError("gap and max_delay parameters cannot be omitted from the parameters dict. "
@@ -59,25 +58,41 @@ class TimeSeriesClassificationPipeline(ClassificationPipeline):
         y = _convert_woodwork_types_wrapper(y.to_series())
         self._encoder.fit(y)
         y = self._encode_targets(y)
-
         X_t = self._compute_features_during_fit(X, y)
-        if X_t.empty:
-            raise RuntimeError("Pipeline computed empty features during call to .fit. This means "
-                               "that either 1) you passed in X=None to fit and don't have a DelayFeatureTransformer "
-                               "in your pipeline or 2) you do have a DelayFeatureTransformer but gap=0 and max_delay=0. "
-                               "Please add a DelayFeatureTransformer or change the values of gap and max_delay")
-
+        X_t = _convert_woodwork_types_wrapper(X_t.to_dataframe())
         y_shifted = y.shift(-self.gap)
         X_t, y_shifted = drop_rows_with_nans(X_t, y_shifted)
         self.estimator.fit(X_t, y_shifted)
         return self
 
+    def _estimator_predict(self, features, y):
+        """Get estimator predictions.
+
+        This helper passes y as an argument if needed by the estimator.
+        """
+        y_arg = None
+        if self.estimator.predict_uses_y:
+            y_arg = y
+        return self.estimator.predict(features, y=y_arg)
+
+    def _estimator_predict_proba(self, features, y):
+        """Get estimator predicted probabilities.
+
+        This helper passes y as an argument if needed by the estimator.
+        """
+        y_arg = None
+        if self.estimator.predict_uses_y:
+            y_arg = y
+        return self.estimator.predict_proba(features, y=y_arg)
+
     def _predict(self, X, y, objective=None, pad=False):
-        y_encoded = self._encode_targets(y)
-        features = self.compute_estimator_features(X, y_encoded)
-        predictions = self.estimator.predict(features.dropna(axis=0, how="any"))
+        features = self.compute_estimator_features(X, y)
+        features = _convert_woodwork_types_wrapper(features.to_dataframe())
+        features_no_nan, y_no_nan = drop_rows_with_nans(features, y)
+        predictions = self._estimator_predict(features_no_nan, y_no_nan)
         if pad:
-            return pad_with_nans(predictions, max(0, features.shape[0] - predictions.shape[0]))
+            padded = pad_with_nans(predictions.to_series(), max(0, features.shape[0] - predictions.shape[0]))
+            return _convert_to_woodwork_structure(padded)
         return predictions
 
     def predict(self, X, y=None, objective=None):
@@ -89,15 +104,19 @@ class TimeSeriesClassificationPipeline(ClassificationPipeline):
             objective (Object or string): The objective to use to make predictions
 
         Returns:
-            pd.Series: Predicted values.
+            ww.DataColumn: Predicted values.
         """
         X, y = self._convert_to_woodwork(X, y)
         X = _convert_woodwork_types_wrapper(X.to_dataframe())
         y = _convert_woodwork_types_wrapper(y.to_series())
         n_features = max(len(y), X.shape[0])
         predictions = self._predict(X, y, objective=objective, pad=False)
-        predictions = pd.Series(self._decode_targets(predictions))
-        return pad_with_nans(predictions, max(0, n_features - predictions.shape[0]))
+        predictions = _convert_woodwork_types_wrapper(predictions.to_series())
+        # In case gap is 0 and this is a baseline pipeline, we drop the nans in the
+        # predictions before decoding them
+        predictions = pd.Series(self._decode_targets(predictions.dropna()), name=self.input_target_name)
+        padded = pad_with_nans(predictions, max(0, n_features - predictions.shape[0]))
+        return _convert_to_woodwork_structure(padded)
 
     def predict_proba(self, X, y=None):
         """Make probability estimates for labels.
@@ -106,33 +125,25 @@ class TimeSeriesClassificationPipeline(ClassificationPipeline):
             X (ww.DataTable, pd.DataFrame or np.ndarray): Data of shape [n_samples, n_features]
 
         Returns:
-            pd.DataFrame: Probability estimates
+            ww.DataTable: Probability estimates
         """
         X, y = self._convert_to_woodwork(X, y)
         X = _convert_woodwork_types_wrapper(X.to_dataframe())
         y = _convert_woodwork_types_wrapper(y.to_series())
-        y_encoded = self._encode_targets(y)
-        features = self.compute_estimator_features(X, y_encoded)
-        proba = self.estimator.predict_proba(features.dropna(axis=0, how="any"))
+        features = self.compute_estimator_features(X, y)
+        features = _convert_woodwork_types_wrapper(features.to_dataframe())
+        features_no_nan, y_no_nan = drop_rows_with_nans(features, y)
+        proba = self._estimator_predict_proba(features_no_nan, y_no_nan).to_dataframe()
         proba.columns = self._encoder.classes_
-        return pad_with_nans(proba, max(0, features.shape[0] - proba.shape[0]))
-
-    def _compute_predictions(self, X, y, objectives):
-        """Compute predictions/probabilities based on objectives."""
-        y_predicted = None
-        y_predicted_proba = None
-        if any(o.score_needs_proba for o in objectives):
-            y_predicted_proba = self.predict_proba(X, y)
-        if any(not o.score_needs_proba for o in objectives):
-            y_predicted = self._predict(X, y, pad=True)
-        return y_predicted, y_predicted_proba
+        padded = pad_with_nans(proba, max(0, features.shape[0] - proba.shape[0]))
+        return _convert_to_woodwork_structure(padded)
 
     def score(self, X, y, objectives):
         """Evaluate model performance on current and additional objectives.
 
         Arguments:
             X (ww.DataTable, pd.DataFrame or np.ndarray): Data of shape [n_samples, n_features]
-            y (pd.Series, ww.DataColumn): True labels of length [n_samples]
+            y (ww.DataColumn, pd.Series): True labels of length [n_samples]
             objectives (list): Non-empty list of objectives to score on
 
         Returns:
@@ -145,15 +156,14 @@ class TimeSeriesClassificationPipeline(ClassificationPipeline):
 
         y_encoded = self._encode_targets(y)
         y_shifted = y_encoded.shift(-self.gap)
-        y_pred, y_pred_proba = self._compute_predictions(X, y, objectives)
-        non_nan_mask = _get_rows_without_nans(y_shifted, y_pred, y_pred_proba)
-        if y_pred is not None:
-            y_pred = y_pred.iloc[non_nan_mask]
-        if y_pred_proba is not None:
-            y_pred_proba = y_pred_proba.iloc[non_nan_mask]
-        y_labels = y_shifted.iloc[non_nan_mask]
-        return self._score_all_objectives(X, y_labels, y_pred,
-                                          y_pred_proba=y_pred_proba,
+        y_predicted, y_predicted_proba = self._compute_predictions(X, y, objectives, time_series=True)
+        if y_predicted is not None:
+            y_predicted = _convert_woodwork_types_wrapper(y_predicted.to_series())
+        if y_predicted_proba is not None:
+            y_predicted_proba = _convert_woodwork_types_wrapper(y_predicted_proba.to_dataframe())
+        y_shifted, y_predicted, y_predicted_proba = drop_rows_with_nans(y_shifted, y_predicted, y_predicted_proba)
+        return self._score_all_objectives(X, y_shifted, y_predicted,
+                                          y_pred_proba=y_predicted_proba,
                                           objectives=objectives)
 
 
@@ -170,9 +180,9 @@ class TimeSeriesBinaryClassificationPipeline(TimeSeriesClassificationPipeline):
         self._threshold = value
 
     def _predict(self, X, y, objective=None, pad=False):
-        y_encoded = self._encode_targets(y)
-        features = self.compute_estimator_features(X, y_encoded)
-        features_no_nan = features.dropna(axis=0, how="any")
+        features = self.compute_estimator_features(X, y)
+        features = _convert_woodwork_types_wrapper(features.to_dataframe())
+        features_no_nan, y_no_nan = drop_rows_with_nans(features, y)
 
         if objective is not None:
             objective = get_objective(objective, return_instance=True)
@@ -180,16 +190,17 @@ class TimeSeriesBinaryClassificationPipeline(TimeSeriesClassificationPipeline):
                 raise ValueError(f"Objective {objective.name} is not defined for time series binary classification.")
 
         if self.threshold is None:
-            predictions = self.estimator.predict(features_no_nan)
+            predictions = self._estimator_predict(features_no_nan, y_no_nan).to_series()
         else:
-            ypred_proba = self.estimator.predict_proba(features_no_nan).iloc[:, 1]
+            proba = self._estimator_predict_proba(features_no_nan, y_no_nan).to_dataframe()
+            proba = proba.iloc[:, 1]
             if objective is None:
-                predictions = ypred_proba > self.threshold
+                predictions = proba > self.threshold
             else:
-                predictions = objective.decision_function(ypred_proba, threshold=self.threshold, X=features_no_nan)
+                predictions = objective.decision_function(proba, threshold=self.threshold, X=features_no_nan)
         if pad:
-            return pad_with_nans(predictions, max(0, features.shape[0] - predictions.shape[0]))
-        return predictions
+            predictions = pad_with_nans(predictions, max(0, features.shape[0] - predictions.shape[0]))
+        return _convert_to_woodwork_structure(predictions)
 
     @staticmethod
     def _score(X, y, predictions, objective):
