@@ -27,7 +27,7 @@ class TimeSeriesRegressionPipeline(RegressionPipeline):
                  An empty dictionary {} implies using all default values for component parameters. Pipeline-level
                  parameters such as gap and max_delay must be specified with the "pipeline" key. For example:
                  Pipeline(parameters={"pipeline": {"max_delay": 4, "gap": 2}}).
-            random_state (int, np.random.RandomState): The random seed/state. Defaults to 0.
+            random_state (int): Seed for the random number generator. Defaults to 0.
         """
         if "pipeline" not in parameters:
             raise ValueError("gap and max_delay parameters cannot be omitted from the parameters dict. "
@@ -54,13 +54,8 @@ class TimeSeriesRegressionPipeline(RegressionPipeline):
         y = _convert_to_woodwork_structure(y)
         X = _convert_woodwork_types_wrapper(X.to_dataframe())
         y = _convert_woodwork_types_wrapper(y.to_series())
-
         X_t = self._compute_features_during_fit(X, y)
-        if X_t.empty:
-            raise RuntimeError("Pipeline computed empty features during call to .fit. This means "
-                               "that either 1) you passed in X=None to fit and don't have a DelayFeatureTransformer "
-                               "in your pipeline or 2) you do have a DelayFeatureTransformer but gap=0 and max_delay=0. "
-                               "Please add a DelayFeatureTransformer or change the values of gap and max_delay")
+        X_t = X_t.to_dataframe()
 
         y_shifted = y.shift(-self.gap)
         X_t, y_shifted = drop_rows_with_nans(X_t, y_shifted)
@@ -76,7 +71,7 @@ class TimeSeriesRegressionPipeline(RegressionPipeline):
             objective (Object or string): The objective to use to make predictions
 
         Returns:
-            pd.Series: Predicted values.
+            ww.DataColumn: Predicted values.
         """
         if X is None:
             X = pd.DataFrame()
@@ -84,10 +79,16 @@ class TimeSeriesRegressionPipeline(RegressionPipeline):
         y = _convert_to_woodwork_structure(y)
         X = _convert_woodwork_types_wrapper(X.to_dataframe())
         y = _convert_woodwork_types_wrapper(y.to_series())
-
         features = self.compute_estimator_features(X, y)
-        predictions = self.estimator.predict(features.dropna(axis=0, how="any"))
-        return pad_with_nans(predictions, max(0, features.shape[0] - predictions.shape[0]))
+        features = _convert_woodwork_types_wrapper(features.to_dataframe())
+        features_no_nan, y = drop_rows_with_nans(features, y)
+        y_arg = None
+        if self.estimator.predict_uses_y:
+            y_arg = y
+        predictions = self.estimator.predict(features_no_nan, y_arg).to_series()
+        predictions = predictions.rename(self.input_target_name)
+        padded = pad_with_nans(predictions, max(0, features.shape[0] - predictions.shape[0]))
+        return _convert_to_woodwork_structure(padded)
 
     def score(self, X, y, objectives):
         """Evaluate model performance on current and additional objectives.
@@ -109,6 +110,8 @@ class TimeSeriesRegressionPipeline(RegressionPipeline):
         y = _convert_woodwork_types_wrapper(y.to_series())
 
         y_predicted = self.predict(X, y)
+        y_predicted = _convert_woodwork_types_wrapper(y_predicted.to_series())
+
         y_shifted = y.shift(-self.gap)
         objectives = [get_objective(o, return_instance=True) for o in objectives]
         y_shifted, y_predicted = drop_rows_with_nans(y_shifted, y_predicted)
