@@ -8,6 +8,7 @@ import cloudpickle
 import numpy as np
 import pandas as pd
 import pytest
+import woodwork as ww
 from skopt.space import Categorical
 
 from evalml.exceptions import (
@@ -49,8 +50,10 @@ from evalml.pipelines.components import (
     SelectColumns,
     SimpleImputer,
     StandardScaler,
+    SVMClassifier,
+    SVMRegressor,
     TextFeaturizer,
-    TimeSeriesBaselineRegressor,
+    TimeSeriesBaselineEstimator,
     Transformer,
     XGBoostClassifier,
     XGBoostRegressor
@@ -61,7 +64,6 @@ from evalml.pipelines.components.ensemble import (
 )
 from evalml.pipelines.components.utils import (
     _all_estimators,
-    _all_estimators_used_in_search,
     _all_transformers,
     all_components,
     generate_component_code
@@ -189,6 +191,8 @@ def test_describe_component():
     rf_classifier = RandomForestClassifier(n_estimators=10, max_depth=3)
     rf_regressor = RandomForestRegressor(n_estimators=10, max_depth=3)
     linear_regressor = LinearRegressor()
+    svm_classifier = SVMClassifier()
+    svm_regressor = SVMRegressor()
     assert base_classifier.describe(return_dict=True) == {'name': 'Baseline Classifier', 'parameters': {'strategy': 'mode'}}
     assert base_regressor.describe(return_dict=True) == {'name': 'Baseline Regressor', 'parameters': {'strategy': 'mean'}}
     assert lr_classifier.describe(return_dict=True) == {'name': 'Logistic Regression Classifier', 'parameters': {'penalty': 'l2', 'C': 1.0, 'n_jobs': -1, 'multi_class': 'auto', 'solver': 'lbfgs'}}
@@ -199,6 +203,8 @@ def test_describe_component():
     assert rf_classifier.describe(return_dict=True) == {'name': 'Random Forest Classifier', 'parameters': {'n_estimators': 10, 'max_depth': 3, 'n_jobs': -1}}
     assert rf_regressor.describe(return_dict=True) == {'name': 'Random Forest Regressor', 'parameters': {'n_estimators': 10, 'max_depth': 3, 'n_jobs': -1}}
     assert linear_regressor.describe(return_dict=True) == {'name': 'Linear Regressor', 'parameters': {'fit_intercept': True, 'normalize': False, 'n_jobs': -1}}
+    assert svm_classifier.describe(return_dict=True) == {'name': 'SVM Classifier', 'parameters': {'C': 1.0, 'kernel': 'rbf', 'gamma': 'scale', 'probability': True}}
+    assert svm_regressor.describe(return_dict=True) == {'name': 'SVM Regressor', 'parameters': {'C': 1.0, 'kernel': 'rbf', 'gamma': 'scale'}}
     try:
         xgb_classifier = XGBoostClassifier(eta=0.1, min_child_weight=1, max_depth=3, n_estimators=75)
         xgb_regressor = XGBoostRegressor(eta=0.1, min_child_weight=1, max_depth=3, n_estimators=75)
@@ -253,7 +259,7 @@ def test_missing_methods_on_components(X_y_binary, test_classes):
         name = "Mock Transformer"
 
         def fit(self, X, y=None):
-            return X
+            return self
 
     component = MockComponent()
     with pytest.raises(MethodPropertyNotFoundError, match="Component requires a fit method or a component_obj that implements fit"):
@@ -313,7 +319,7 @@ def test_component_fit_transform(X_y_binary):
         hyperparameter_ranges = {}
 
         def fit_transform(self, X, y=None):
-            return X
+            return ww.DataTable(X)
 
         def __init__(self):
             parameters = {}
@@ -342,7 +348,7 @@ def test_component_fit_transform(X_y_binary):
             return self
 
         def transform(self, X, y=None):
-            return X
+            return ww.DataTable(X)
 
         def __init__(self):
             parameters = {}
@@ -369,14 +375,14 @@ def test_component_fit_transform(X_y_binary):
     y = pd.Series(y)
 
     component = MockTransformerWithFitTransform()
-    assert isinstance(component.fit_transform(X, y), pd.DataFrame)
+    assert isinstance(component.fit_transform(X, y), ww.DataTable)
 
     component = MockTransformerWithFitTransformButError()
     with pytest.raises(RuntimeError):
         component.fit_transform(X, y)
 
     component = MockTransformerWithFitAndTransform()
-    assert isinstance(component.fit_transform(X, y), pd.DataFrame)
+    assert isinstance(component.fit_transform(X, y), ww.DataTable)
 
     component = MockTransformerWithOnlyFit()
     with pytest.raises(MethodPropertyNotFoundError):
@@ -440,34 +446,22 @@ def test_clone_init():
     clf = MockFitComponent(**params)
     clf_clone = clf.clone()
     assert clf.parameters == clf_clone.parameters
-
-
-def test_clone_random_state():
-    params = {'param_a': 1, 'param_b': 1}
-
-    clf = MockFitComponent(**params, random_state=np.random.RandomState(42))
-    clf_clone = clf.clone(random_state=np.random.RandomState(42))
-    assert clf_clone.random_state.randint(2**30) == clf.random_state.randint(2**30)
-
-    clf = MockFitComponent(**params, random_state=2)
-    clf_clone = clf.clone(random_state=2)
-    assert clf_clone.random_state.randint(2**30) == clf.random_state.randint(2**30)
+    assert clf_clone.random_state == clf.random_state
 
 
 def test_clone_fitted(X_y_binary):
     X, y = X_y_binary
     params = {'param_a': 3, 'param_b': 7}
     clf = MockFitComponent(**params)
-    random_state_first_val = clf.random_state.randint(2**30)
-
     clf.fit(X, y)
     predicted = clf.predict(X)
 
     clf_clone = clf.clone()
-    assert clf_clone.random_state.randint(2**30) == random_state_first_val
+    assert clf_clone.random_state == clf.random_state
+    assert clf.parameters == clf_clone.parameters
+
     with pytest.raises(ComponentNotYetFittedError, match='You must fit'):
         clf_clone.predict(X)
-    assert clf.parameters == clf_clone.parameters
 
     clf_clone.fit(X, y)
     predicted_clone = clf_clone.predict(X)
@@ -535,85 +529,38 @@ def test_transformer_transform_output_type(X_y_binary):
 
             component.fit(X, y=y)
             transform_output = component.transform(X, y=y)
-            assert isinstance(transform_output, pd.DataFrame)
+            assert isinstance(transform_output, ww.DataTable)
 
             if isinstance(component, SelectColumns):
                 assert transform_output.shape == (X.shape[0], 0)
-                assert isinstance(transform_output.columns, pd.Index)
             elif isinstance(component, PCA) or isinstance(component, LinearDiscriminantAnalysis):
                 assert transform_output.shape[0] == X.shape[0]
                 assert transform_output.shape[1] <= X.shape[1]
-                assert isinstance(transform_output.columns, pd.Index)
             elif isinstance(component, DFSTransformer):
                 assert transform_output.shape[0] == X.shape[0]
                 assert transform_output.shape[1] >= X.shape[1]
-                assert isinstance(transform_output.columns, pd.Index)
             elif isinstance(component, DelayedFeatureTransformer):
                 # We just want to check that DelayedFeaturesTransformer outputs a DataFrame
                 # The dataframe shape and index are checked in test_delayed_features_transformer.py
                 continue
             else:
                 assert transform_output.shape == X.shape
-                assert (transform_output.columns == X_cols_expected).all()
+                assert (list(transform_output.columns) == list(X_cols_expected))
 
             transform_output = component.fit_transform(X, y=y)
-            assert isinstance(transform_output, pd.DataFrame)
+            assert isinstance(transform_output, ww.DataTable)
 
             if isinstance(component, SelectColumns):
                 assert transform_output.shape == (X.shape[0], 0)
-                assert isinstance(transform_output.columns, pd.Index)
             elif isinstance(component, PCA) or isinstance(component, LinearDiscriminantAnalysis):
                 assert transform_output.shape[0] == X.shape[0]
                 assert transform_output.shape[1] <= X.shape[1]
-                assert isinstance(transform_output.columns, pd.Index)
             elif isinstance(component, DFSTransformer):
                 assert transform_output.shape[0] == X.shape[0]
                 assert transform_output.shape[1] >= X.shape[1]
-                assert isinstance(transform_output.columns, pd.Index)
             else:
                 assert transform_output.shape == X.shape
-                assert (transform_output.columns == X_cols_expected).all()
-
-
-def test_estimator_predict_output_type(X_y_binary, helper_functions):
-    X_np, y_np = X_y_binary
-    assert isinstance(X_np, np.ndarray)
-    assert isinstance(y_np, np.ndarray)
-    y_list = list(y_np)
-    X_df_no_col_names = pd.DataFrame(X_np)
-    range_index = pd.RangeIndex(start=0, stop=X_np.shape[1], step=1)
-    X_df_with_col_names = pd.DataFrame(X_np, columns=['x' + str(i) for i in range(X_np.shape[1])])
-    y_series_no_name = pd.Series(y_np)
-    y_series_with_name = pd.Series(y_np, name='target')
-    datatype_combos = [(X_np, y_np, range_index, np.unique(y_np)),
-                       (X_np, y_list, range_index, np.unique(y_np)),
-                       (X_df_no_col_names, y_series_no_name, range_index, y_series_no_name.unique()),
-                       (X_df_with_col_names, y_series_with_name, X_df_with_col_names.columns, y_series_with_name.unique())]
-
-    for component_class in _all_estimators_used_in_search():
-        for X, y, X_cols_expected, y_cols_expected in datatype_combos:
-            print('Checking output of predict for estimator "{}" on X type {} cols {}, y type {} name {}'
-                  .format(component_class.name, type(X),
-                          X.columns if isinstance(X, pd.DataFrame) else None, type(y),
-                          y.name if isinstance(y, pd.Series) else None))
-            component = helper_functions.safe_init_component_with_njobs_1(component_class)
-            component.fit(X, y=y)
-            predict_output = component.predict(X)
-            assert isinstance(predict_output, pd.Series)
-            assert len(predict_output) == len(y)
-            assert predict_output.name is None
-
-            if not ((ProblemTypes.BINARY in component_class.supported_problem_types) or
-                    (ProblemTypes.MULTICLASS in component_class.supported_problem_types)):
-                continue
-            print('Checking output of predict_proba for estimator "{}" on X type {} cols {}, y type {} name {}'
-                  .format(component_class.name, type(X),
-                          X.columns if isinstance(X, pd.DataFrame) else None, type(y),
-                          y.name if isinstance(y, pd.Series) else None))
-            predict_proba_output = component.predict_proba(X)
-            assert isinstance(predict_proba_output, pd.DataFrame)
-            assert predict_proba_output.shape == (len(y), len(np.unique(y)))
-            assert (predict_proba_output.columns == y_cols_expected).all()
+                assert (list(transform_output.columns) == list(X_cols_expected))
 
 
 @pytest.mark.parametrize("cls", [cls for cls in all_components() if cls not in [StackedEnsembleRegressor, StackedEnsembleClassifier]])
@@ -635,13 +582,13 @@ def test_estimator_check_for_fit(X_y_binary):
             pass
 
         def fit(self, X, y):
-            pass
+            return self
 
         def predict(self, X):
-            pass
+            return ww.DataColumn(pd.Series())
 
         def predict_proba(self, X):
-            pass
+            return ww.DataTable(pd.DataFrame())
 
     class MockEstimator(Estimator):
         name = "Mock Estimator"
@@ -664,63 +611,16 @@ def test_estimator_check_for_fit(X_y_binary):
     est.predict_proba(X)
 
 
-def test_estimator_check_for_fit_with_overrides(X_y_binary):
-    class MockEstimatorWithOverrides(Estimator):
-        name = "Mock Estimator"
-        model_family = ModelFamily.LINEAR_MODEL
-        supported_problem_types = ['binary']
-
-        def fit(self, X, y):
-            pass
-
-        def predict(self, X):
-            pass
-
-        def predict_proba(self, X):
-            pass
-
-    class MockEstimatorWithOverridesSubclass(Estimator):
-        name = "Mock Estimator Subclass"
-        model_family = ModelFamily.LINEAR_MODEL
-        supported_problem_types = ['binary']
-
-        def fit(self, X, y):
-            pass
-
-        def predict(self, X):
-            pass
-
-        def predict_proba(self, X):
-            pass
-
-    X, y = X_y_binary
-    est = MockEstimatorWithOverrides()
-    est_subclass = MockEstimatorWithOverridesSubclass()
-
-    with pytest.raises(ComponentNotYetFittedError, match='You must fit'):
-        est.predict(X)
-    with pytest.raises(ComponentNotYetFittedError, match='You must fit'):
-        est_subclass.predict(X)
-
-    est.fit(X, y)
-    est.predict(X)
-    est.predict_proba(X)
-
-    est_subclass.fit(X, y)
-    est_subclass.predict(X)
-    est_subclass.predict_proba(X)
-
-
 def test_transformer_check_for_fit(X_y_binary):
     class MockTransformerObj():
         def __init__(self):
             pass
 
         def fit(self, X, y):
-            pass
+            return self
 
-        def transform(self, X):
-            pass
+        def transform(self, X, y=None):
+            return ww.DataTable(X)
 
     class MockTransformer(Transformer):
         name = "Mock Transformer"
@@ -743,19 +643,19 @@ def test_transformer_check_for_fit_with_overrides(X_y_binary):
         name = "Mock Transformer"
 
         def fit(self, X, y):
-            pass
+            return self
 
         def transform(self, X):
-            pass
+            return ww.DataTable(pd.DataFrame())
 
     class MockTransformerWithOverrideSubclass(Transformer):
         name = "Mock Transformer Subclass"
 
         def fit(self, X, y):
-            pass
+            return self
 
         def transform(self, X):
-            pass
+            return ww.DataTable(pd.DataFrame())
 
     X, y = X_y_binary
     transformer = MockTransformerWithOverride()
@@ -800,7 +700,7 @@ def test_all_transformers_check_fit(X_y_binary):
 
 def test_all_estimators_check_fit(X_y_binary, test_estimator_needs_fitting_false, helper_functions):
     X, y = X_y_binary
-    estimators_to_check = [estimator for estimator in _all_estimators() if estimator not in [StackedEnsembleClassifier, StackedEnsembleRegressor, TimeSeriesBaselineRegressor]] + [test_estimator_needs_fitting_false]
+    estimators_to_check = [estimator for estimator in _all_estimators() if estimator not in [StackedEnsembleClassifier, StackedEnsembleRegressor, TimeSeriesBaselineEstimator]] + [test_estimator_needs_fitting_false]
     for component_class in estimators_to_check:
         if not component_class.needs_fitting:
             continue
@@ -825,6 +725,19 @@ def test_all_estimators_check_fit(X_y_binary, test_estimator_needs_fitting_false
         component.feature_importance
 
 
+@pytest.mark.parametrize("data_type", ['li', 'np', 'pd', 'ww'])
+def test_all_transformers_check_fit_input_type(data_type, X_y_binary, make_data_type):
+    X, y = X_y_binary
+    X = make_data_type(data_type, X)
+    y = make_data_type(data_type, y)
+    for component_class in _all_transformers():
+        if not component_class.needs_fitting:
+            continue
+
+        component = component_class()
+        component.fit(X, y)
+
+
 def test_no_fitting_required_components(X_y_binary, test_estimator_needs_fitting_false, helper_functions):
     X, y = X_y_binary
     for component_class in all_components() + [test_estimator_needs_fitting_false]:
@@ -845,9 +758,9 @@ def test_serialization(X_y_binary, tmpdir, helper_functions):
             component = helper_functions.safe_init_component_with_njobs_1(component_class)
         except EnsembleMissingPipelinesError:
             if (component_class == StackedEnsembleClassifier):
-                component = component_class(input_pipelines=[make_pipeline_from_components([RandomForestClassifier()], ProblemTypes.BINARY)])
+                component = component_class(input_pipelines=[make_pipeline_from_components([RandomForestClassifier()], ProblemTypes.BINARY)], n_jobs=1)
             elif (component_class == StackedEnsembleRegressor):
-                component = component_class(input_pipelines=[make_pipeline_from_components([RandomForestRegressor()], ProblemTypes.REGRESSION)])
+                component = component_class(input_pipelines=[make_pipeline_from_components([RandomForestRegressor()], ProblemTypes.REGRESSION)], n_jobs=1)
         component.fit(X, y)
 
         for pickle_protocol in range(cloudpickle.DEFAULT_PROTOCOL + 1):
