@@ -40,10 +40,11 @@ def test_fit_predict(X_y_regression):
     y_pred_sk = sk_clf.predict(X)
 
     clf = ElasticNetRegressor()
-    clf.fit(X, y)
-    y_pred = clf.predict(X)
+    fitted = clf.fit(X, y)
+    assert isinstance(fitted, ElasticNetRegressor)
 
-    np.testing.assert_almost_equal(y_pred, y_pred_sk, decimal=5)
+    y_pred = clf.predict(X)
+    np.testing.assert_almost_equal(y_pred_sk, y_pred.to_series().values, decimal=5)
 
 
 def test_feature_importance(X_y_regression):
