@@ -11,13 +11,16 @@ def test_lda_invalid_init():
         LinearDiscriminantAnalysis(n_components=-1)
 
 
-def test_lda_numeric():
+@pytest.mark.parametrize('data_type', ['pd', 'ww'])
+def test_lda_numeric(data_type, make_data_type):
     X = pd.DataFrame([[3, 0, 1, 6],
                       [1, 2, 1, 6],
                       [10, 2, 1, 6],
                       [10, 2, 2, 5],
                       [6, 2, 2, 5]])
-    y = [0, 1, 0, 1, 1]
+    y = pd.Series([0, 1, 0, 1, 1])
+    X = make_data_type(data_type, X)
+    y = make_data_type(data_type, y)
     lda = LinearDiscriminantAnalysis()
     expected_X_t = pd.DataFrame([[-3.7498560857993817],
                                  [1.984459921694517],
@@ -25,17 +28,17 @@ def test_lda_numeric():
                                  [1.3401547523131798],
                                  [3.659653362085993]],
                                 columns=["component_0"])
-    X_t = pd.DataFrame(lda.fit_transform(X, y))
-    assert_frame_equal(X_t, expected_X_t)
+    X_t = lda.fit_transform(X, y)
+    assert_frame_equal(expected_X_t, X_t.to_dataframe())
 
 
 def test_lda_array():
-    X = [[3, 0, 1, 6],
-         [1, 2, 1, 6],
-         [10, 2, 1, 6],
-         [10, 2, 2, 5],
-         [6, 2, 2, 5]]
-    y = [2, 2, 0, 1, 0]
+    X = np.array([[3, 0, 1, 6],
+                  [1, 2, 1, 6],
+                  [10, 2, 1, 6],
+                  [10, 2, 2, 5],
+                  [6, 2, 2, 5]])
+    y = np.array([2, 2, 0, 1, 0])
     lda = LinearDiscriminantAnalysis()
     expected_X_t = pd.DataFrame([[-0.6412164311777084, 0.5197032695565076],
                                  [0.9499648898073094, -0.6919658287324498],
@@ -44,8 +47,8 @@ def test_lda_array():
                                  [-0.4751798337481819, -0.7065437888758568]],
                                 columns=[f"component_{i}" for i in range(2)])
     lda.fit(X, y)
-    X_t = pd.DataFrame(lda.transform(X))
-    assert_frame_equal(X_t, expected_X_t)
+    X_t = lda.transform(X)
+    assert_frame_equal(expected_X_t, X_t.to_dataframe())
 
 
 def test_lda_invalid():
@@ -90,11 +93,11 @@ def test_n_components():
     y = [0, 3, 3, 1, 2, 0, 2]
 
     lda = LinearDiscriminantAnalysis(n_components=3)
-    X_t = pd.DataFrame(lda.fit_transform(X, y))
+    X_t = lda.fit_transform(X, y)
     assert X_t.shape[1] == 3
 
     lda = LinearDiscriminantAnalysis(n_components=1)
-    X_t = pd.DataFrame(lda.fit_transform(X, y))
+    X_t = lda.fit_transform(X, y)
     assert X_t.shape[1] == 1
 
 
