@@ -6,12 +6,14 @@ from pandas.testing import assert_frame_equal
 from evalml.pipelines.components import PCA
 
 
-def test_pca_numeric():
+@pytest.mark.parametrize('data_type', ['pd', 'ww'])
+def test_pca_numeric(data_type, make_data_type):
     X = pd.DataFrame([[3, 0, 1, 6],
                       [1, 2, 1, 6],
                       [10, 2, 1, 6],
                       [10, 2, 2, 5],
                       [6, 2, 2, 5]])
+    X = make_data_type(data_type, X)
     pca = PCA()
     expected_X_t = pd.DataFrame([[3.176246, 1.282616],
                                  [4.969987, -0.702976],
@@ -19,8 +21,8 @@ def test_pca_numeric():
                                  [-4.079174, -0.252790],
                                  [-0.112877, -0.755922]],
                                 columns=[f"component_{i}" for i in range(2)])
-    X_t = pd.DataFrame(pca.fit_transform(X))
-    assert_frame_equal(X_t, expected_X_t)
+    X_t = pca.fit_transform(X)
+    assert_frame_equal(expected_X_t, X_t.to_dataframe())
 
 
 def test_pca_array():
@@ -37,8 +39,8 @@ def test_pca_array():
                                  [-0.112877, -0.755922]],
                                 columns=[f"component_{i}" for i in range(2)])
     pca.fit(X)
-    X_t = pd.DataFrame(pca.transform(X))
-    assert_frame_equal(X_t, expected_X_t)
+    X_t = pca.transform(X)
+    assert_frame_equal(expected_X_t, X_t.to_dataframe())
 
 
 def test_pca_invalid():
@@ -84,15 +86,15 @@ def test_variance():
                                  [7.067179, 0.645894, -2.633617, 2.159135],
                                  [6.828241, -3.867796, 2.597358, -1.740404]],
                                 columns=[f"component_{i}" for i in range(4)])
-    X_t_90 = pd.DataFrame(pca.fit_transform(X))
-    assert_frame_equal(X_t_90, expected_X_t)
+    X_t_90 = pca.fit_transform(X)
+    assert_frame_equal(expected_X_t, X_t_90.to_dataframe())
 
     pca = PCA(variance=0.75)
-    X_t_75 = pd.DataFrame(pca.fit_transform(X))
+    X_t_75 = pca.fit_transform(X)
     assert X_t_75.shape[1] < X_t_90.shape[1]
 
     pca = PCA(variance=0.50)
-    X_t_50 = pd.DataFrame(pca.fit_transform(X))
+    X_t_50 = pca.fit_transform(X)
     assert X_t_50.shape[1] < X_t_75.shape[1]
 
 
@@ -103,13 +105,13 @@ def test_n_components():
                       [10, 6, 4, 4, 0, 1],
                       [6, 8, 9, 3, 1, 5]])
     pca = PCA(n_components=5)
-    X_t = pd.DataFrame(pca.fit_transform(X))
+    X_t = pca.fit_transform(X)
     assert X_t.shape[1] == 5
 
     pca = PCA(n_components=3)
-    X_t = pd.DataFrame(pca.fit_transform(X))
+    X_t = pca.fit_transform(X)
     assert X_t.shape[1] == 3
 
     pca = PCA(n_components=1)
-    X_t = pd.DataFrame(pca.fit_transform(X))
+    X_t = pca.fit_transform(X)
     assert X_t.shape[1] == 1
