@@ -3,6 +3,7 @@ from unittest.mock import patch
 import numpy as np
 import pandas as pd
 import pytest
+import woodwork as ww
 
 from evalml.exceptions import EnsembleMissingPipelinesError
 from evalml.model_family import ModelFamily
@@ -13,7 +14,6 @@ from evalml.pipelines.components import (
 from evalml.pipelines.components.ensemble import StackedEnsembleClassifier
 from evalml.pipelines.utils import make_pipeline_from_components
 from evalml.problem_types import ProblemTypes
-from evalml.utils.gen_utils import check_random_state_equality
 
 
 def test_stacked_model_family():
@@ -23,7 +23,7 @@ def test_stacked_model_family():
 def test_stacked_default_parameters():
     assert StackedEnsembleClassifier.default_parameters == {'final_estimator': None,
                                                             'cv': None,
-                                                            'n_jobs': 1
+                                                            'n_jobs': -1
                                                             }
 
 
@@ -51,7 +51,7 @@ def test_stacked_ensemble_init_with_multiple_same_estimators(X_y_binary, logisti
     X, y = X_y_binary
     input_pipelines = [logistic_regression_binary_pipeline_class(parameters={}),
                        logistic_regression_binary_pipeline_class(parameters={})]
-    clf = StackedEnsembleClassifier(input_pipelines=input_pipelines)
+    clf = StackedEnsembleClassifier(input_pipelines=input_pipelines, n_jobs=1)
     expected_parameters = {
         "input_pipelines": input_pipelines,
         "final_estimator": None,
@@ -59,10 +59,30 @@ def test_stacked_ensemble_init_with_multiple_same_estimators(X_y_binary, logisti
         'n_jobs': 1
     }
     assert clf.parameters == expected_parameters
+
+    fitted = clf.fit(X, y)
+    assert isinstance(fitted, StackedEnsembleClassifier)
+
+    y_pred = clf.predict(X)
+    assert len(y_pred) == len(y)
+    assert not np.isnan(y_pred.to_series()).all()
+
+
+def test_stacked_ensemble_n_jobs_negative_one(X_y_binary, logistic_regression_binary_pipeline_class):
+    X, y = X_y_binary
+    input_pipelines = [logistic_regression_binary_pipeline_class(parameters={})]
+    clf = StackedEnsembleClassifier(input_pipelines=input_pipelines, n_jobs=-1)
+    expected_parameters = {
+        "input_pipelines": input_pipelines,
+        "final_estimator": None,
+        'cv': None,
+        'n_jobs': -1
+    }
+    assert clf.parameters == expected_parameters
     clf.fit(X, y)
     y_pred = clf.predict(X)
     assert len(y_pred) == len(y)
-    assert not np.isnan(y_pred).all()
+    assert not np.isnan(y_pred.to_series()).all()
 
 
 @patch('evalml.pipelines.components.ensemble.StackedEnsembleClassifier._stacking_estimator_class')
@@ -70,24 +90,25 @@ def test_stacked_ensemble_does_not_overwrite_pipeline_random_state(mock_stack,
                                                                    logistic_regression_binary_pipeline_class):
     input_pipelines = [logistic_regression_binary_pipeline_class(parameters={}, random_state=3),
                        logistic_regression_binary_pipeline_class(parameters={}, random_state=4)]
-    clf = StackedEnsembleClassifier(input_pipelines=input_pipelines, random_state=5)
+    clf = StackedEnsembleClassifier(input_pipelines=input_pipelines, random_state=5, n_jobs=1)
     estimators_used_in_ensemble = mock_stack.call_args[1]['estimators']
-    assert check_random_state_equality(clf.random_state, np.random.RandomState(5))
-    assert check_random_state_equality(estimators_used_in_ensemble[0][1].pipeline.random_state, np.random.RandomState(3))
-    assert check_random_state_equality(estimators_used_in_ensemble[1][1].pipeline.random_state, np.random.RandomState(4))
+    assert clf.random_state == 5
+    assert estimators_used_in_ensemble[0][1].pipeline.random_state == 3
+    assert estimators_used_in_ensemble[1][1].pipeline.random_state == 4
 
 
 def test_stacked_ensemble_multilevel(logistic_regression_binary_pipeline_class):
     # checks passing a stacked ensemble classifier as a final estimator
     X = pd.DataFrame(np.random.rand(50, 5))
     y = pd.Series([1, 0] * 25)
-    base = StackedEnsembleClassifier(input_pipelines=[logistic_regression_binary_pipeline_class(parameters={})])
+    base = StackedEnsembleClassifier(input_pipelines=[logistic_regression_binary_pipeline_class(parameters={})], n_jobs=1)
     clf = StackedEnsembleClassifier(input_pipelines=[logistic_regression_binary_pipeline_class(parameters={})],
-                                    final_estimator=base)
+                                    final_estimator=base,
+                                    n_jobs=1)
     clf.fit(X, y)
     y_pred = clf.predict(X)
     assert len(y_pred) == len(y)
-    assert not np.isnan(y_pred).all()
+    assert not np.isnan(y_pred.to_series()).all()
 
 
 def test_stacked_problem_types():
@@ -109,29 +130,29 @@ def test_stacked_fit_predict_classification(X_y_binary, X_y_multi, stackable_cla
 
     input_pipelines = [make_pipeline_from_components([classifier], problem_type)
                        for classifier in stackable_classifiers]
-    clf = StackedEnsembleClassifier(input_pipelines=input_pipelines)
+    clf = StackedEnsembleClassifier(input_pipelines=input_pipelines, n_jobs=1)
     clf.fit(X, y)
     y_pred = clf.predict(X)
     assert len(y_pred) == len(y)
-    assert isinstance(y_pred, pd.Series)
-    assert not np.isnan(y_pred).all()
+    assert isinstance(y_pred, ww.DataColumn)
+    assert not np.isnan(y_pred.to_series()).all()
 
     y_pred_proba = clf.predict_proba(X)
-    assert isinstance(y_pred_proba, pd.DataFrame)
+    assert isinstance(y_pred_proba, ww.DataTable)
     assert y_pred_proba.shape == (len(y), num_classes)
-    assert not np.isnan(y_pred_proba).all().all()
+    assert not np.isnan(y_pred_proba.to_dataframe()).all().all()
 
-    clf = StackedEnsembleClassifier(input_pipelines=input_pipelines, final_estimator=RandomForestClassifier())
+    clf = StackedEnsembleClassifier(input_pipelines=input_pipelines, final_estimator=RandomForestClassifier(), n_jobs=1)
     clf.fit(X, y)
     y_pred = clf.predict(X)
     assert len(y_pred) == len(y)
-    assert isinstance(y_pred, pd.Series)
-    assert not np.isnan(y_pred).all()
+    assert isinstance(y_pred, ww.DataColumn)
+    assert not np.isnan(y_pred.to_series()).all()
 
     y_pred_proba = clf.predict_proba(X)
     assert y_pred_proba.shape == (len(y), num_classes)
-    assert isinstance(y_pred_proba, pd.DataFrame)
-    assert not np.isnan(y_pred_proba).all().all()
+    assert isinstance(y_pred_proba, ww.DataTable)
+    assert not np.isnan(y_pred_proba.to_dataframe()).all().all()
 
 
 @pytest.mark.parametrize("problem_type", [ProblemTypes.BINARY, ProblemTypes.MULTICLASS])
@@ -143,7 +164,7 @@ def test_stacked_feature_importance(mock_fit, X_y_binary, X_y_multi, stackable_c
         X, y = X_y_multi
     input_pipelines = [make_pipeline_from_components([classifier], problem_type)
                        for classifier in stackable_classifiers]
-    clf = StackedEnsembleClassifier(input_pipelines=input_pipelines)
+    clf = StackedEnsembleClassifier(input_pipelines=input_pipelines, n_jobs=1)
     clf.fit(X, y)
     mock_fit.assert_called()
     clf._is_fitted = True
