@@ -3,23 +3,12 @@ import logging
 import numpy as np
 import pandas as pd
 import pytest
+import woodwork as ww
+from pandas.testing import assert_frame_equal, assert_series_equal
 
 from evalml.pipelines.components import TextFeaturizer
 
 
-@pytest.fixture()
-def text_df():
-    df = pd.DataFrame(
-        {'col_1': ['I\'m singing in the rain! Just singing in the rain, what a glorious feeling, I\'m happy again!',
-                   'In sleep he sang to me, in dreams he came... That voice which calls to me, and speaks my name.',
-                   'I\'m gonna be the main event, like no king was before! I\'m brushing up on looking down, I\'m working on my ROAR!'],
-         'col_2': ['do you hear the people sing? Singing the songs of angry men\n\tIt is the music of a people who will NOT be slaves again!',
-                   'I dreamed a dream in days gone by, when hope was high and life worth living',
-                   'Red, the blood of angry men - black, the dark of ages past']
-         })
-    yield df
-
-
 def test_featurizer_only_text(text_df):
     X = text_df
     tf = TextFeaturizer(text_columns=['col_1', 'col_2'])
@@ -38,7 +27,7 @@ def test_featurizer_only_text(text_df):
     X_t = tf.transform(X)
     assert set(X_t.columns) == expected_col_names
     assert len(X_t.columns) == 10
-    assert X_t.dtypes.all() == np.float64
+    assert set(X_t.logical_types.values()) == {ww.logical_types.Double}
 
 
 def test_featurizer_with_nontext(text_df):
@@ -61,7 +50,7 @@ def test_featurizer_with_nontext(text_df):
     X_t = tf.transform(X)
     assert set(X_t.columns) == expected_col_names
     assert len(X_t.columns) == 11
-    assert X_t.dtypes.all() == np.float64
+    assert set(X_t.logical_types.values()) == {ww.logical_types.Double}
 
 
 def test_featurizer_no_text():
@@ -93,7 +82,7 @@ def test_some_missing_col_names(text_df, caplog):
     X_t = tf.transform(X)
     assert set(X_t.columns) == expected_col_names
     assert len(X_t.columns) == 10
-    assert X_t.dtypes.all() == np.float64
+    assert set(X_t.logical_types.values()) == {ww.logical_types.Double}
 
 
 def test_all_missing_col_names(text_df):
@@ -137,7 +126,7 @@ def test_no_null_output():
     tf = TextFeaturizer(text_columns=['col_1', 'col_2'])
     tf.fit(X)
     X_t = tf.transform(X)
-    assert not X_t.isnull().any().any()
+    assert not X_t.to_dataframe().isnull().any().any()
 
 
 def test_index_col_names():
@@ -160,7 +149,7 @@ def test_index_col_names():
     X_t = tf.transform(X)
     assert set(X_t.columns) == expected_col_names
     assert len(X_t.columns) == 10
-    assert X_t.dtypes.all() == np.float64
+    assert set(X_t.logical_types.values()) == {ww.logical_types.Double}
 
 
 def test_int_col_names():
@@ -187,7 +176,7 @@ def test_int_col_names():
     X_t = tf.transform(X)
     assert set(X_t.columns) == expected_col_names
     assert len(X_t.columns) == 10
-    assert X_t.dtypes.all() == np.float64
+    assert set(X_t.logical_types.values()) == {ww.logical_types.Double}
 
 
 def test_output_null():
@@ -202,7 +191,7 @@ def test_output_null():
     tf = TextFeaturizer(text_columns=['col_1', 'col_2'])
     tf.fit(X)
     X_t = tf.transform(X)
-    assert not X_t.isnull().any().any()
+    assert not X_t.to_dataframe().isnull().any().any()
 
 
 def test_diversity_primitive_output():
@@ -213,10 +202,10 @@ def test_diversity_primitive_output():
     tf = TextFeaturizer(text_columns=['diverse'])
     tf.fit(X)
 
-    expected_features = [1.0, 0.5, 0.75]
+    expected_features = pd.Series([1.0, 0.5, 0.75], name='DIVERSITY_SCORE(diverse)')
     X_t = tf.transform(X)
-    features = X_t['DIVERSITY_SCORE(diverse)']
-    np.testing.assert_almost_equal(features, expected_features)
+    features = X_t['DIVERSITY_SCORE(diverse)'].to_series()
+    assert_series_equal(expected_features, features)
 
 
 def test_lsa_primitive_output():
@@ -227,13 +216,13 @@ def test_lsa_primitive_output():
     tf = TextFeaturizer(text_columns=['lsa'])
     tf.fit(X)
 
-    expected_features = [[0.832, 0.],
-                         [0., 1.],
-                         [0.832, 0.]]
+    expected_features = pd.DataFrame([[0.832, 0.],
+                                      [0., 1.],
+                                      [0.832, 0.]], columns=['LSA(lsa)[0]', 'LSA(lsa)[1]'])
     X_t = tf.transform(X)
     cols = [col for col in X_t.columns if 'LSA' in col]
     features = X_t[cols]
-    np.testing.assert_almost_equal(features, expected_features, decimal=3)
+    assert_frame_equal(expected_features, features.to_dataframe(), atol=1e-3)
 
 
 def test_mean_characters_primitive_output():
@@ -244,10 +233,10 @@ def test_mean_characters_primitive_output():
     tf = TextFeaturizer(text_columns=['mean_characters'])
     tf.fit(X)
 
-    expected_features = [4.11764705882352, 3.45, 3.72727272727]
+    expected_features = pd.Series([4.11764705882352, 3.45, 3.72727272727], name='MEAN_CHARACTERS_PER_WORD(mean_characters)')
     X_t = tf.transform(X)
     features = X_t['MEAN_CHARACTERS_PER_WORD(mean_characters)']
-    np.testing.assert_almost_equal(features, expected_features)
+    assert_series_equal(expected_features, features.to_series())
 
 
 def test_polarity_primitive_output():
@@ -258,7 +247,16 @@ def test_polarity_primitive_output():
     tf = TextFeaturizer(text_columns=['polarity'])
     tf.fit(X)
 
-    expected_features = [0.0, -0.214, 0.602]
+    expected_features = pd.Series([0.0, -0.214, 0.602], name='POLARITY_SCORE(polarity)')
     X_t = tf.transform(X)
     features = X_t['POLARITY_SCORE(polarity)']
-    np.testing.assert_almost_equal(features, expected_features)
+    assert_series_equal(expected_features, features.to_series())
+
+
+def test_featurizer_with_custom_indices(text_df):
+    X = text_df
+    X = X.set_index(pd.Series([2, 5, 19]))
+    tf = TextFeaturizer(text_columns=['col_1', 'col_2'])
+    tf.fit(X)
+    X_t = tf.transform(X)
+    assert not X_t.to_dataframe().isnull().any().any()
