@@ -5,7 +5,7 @@ import pandas as pd
 from pytest import importorskip
 
 from evalml.pipelines.components import XGBoostRegressor
-from evalml.utils import SEED_BOUNDS
+from evalml.utils import SEED_BOUNDS, get_random_state
 
 xgb = importorskip('xgboost', reason='Skipping test because xgboost not installed')
 
@@ -17,44 +17,22 @@ def test_xgboost_regressor_random_state_bounds_seed(X_y_regression):
     X = pd.DataFrame(X, columns=col_names)
     y = pd.Series(y)
     clf = XGBoostRegressor(n_estimators=1, max_depth=1, random_state=SEED_BOUNDS.min_bound)
-    clf.fit(X, y)
+    fitted = clf.fit(X, y)
+    assert isinstance(fitted, XGBoostRegressor)
     clf = XGBoostRegressor(n_estimators=1, max_depth=1, random_state=SEED_BOUNDS.max_bound)
     clf.fit(X, y)
 
 
-def test_xgboost_regressor_random_state_bounds_rng(X_y_regression):
-    """when a RNG is inputted for random_state, ensure the sample we take to get a random seed for xgboost is in xgboost's supported range"""
-
-    def make_mock_random_state(return_value):
-
-        class MockRandomState(np.random.RandomState):
-
-            def randint(self, min_bound, max_bound):
-                return return_value
-        return MockRandomState()
-
-    X, y = X_y_regression
-    col_names = ["col_{}".format(i) for i in range(len(X[0]))]
-    X = pd.DataFrame(X, columns=col_names)
-    y = pd.Series(y)
-    rng = make_mock_random_state(XGBoostRegressor.SEED_MIN)
-    clf = XGBoostRegressor(n_estimators=1, max_depth=1, random_state=rng)
-    clf.fit(X, y)
-    rng = make_mock_random_state(XGBoostRegressor.SEED_MAX)
-    clf = XGBoostRegressor(n_estimators=1, max_depth=1, random_state=rng)
-    clf.fit(X, y)
-
-
 def test_xgboost_feature_name_with_random_ascii(X_y_regression):
     X, y = X_y_regression
     clf = XGBoostRegressor()
-    X = clf.random_state.random((X.shape[0], len(string.printable)))
+    X = get_random_state(clf.random_state).random((X.shape[0], len(string.printable)))
     col_names = ['column_{}'.format(ascii_char) for ascii_char in string.printable]
     X = pd.DataFrame(X, columns=col_names)
     clf.fit(X, y)
     predictions = clf.predict(X)
     assert len(predictions) == len(y)
-    assert not np.isnan(predictions).all()
+    assert not np.isnan(predictions.to_series()).all()
 
     assert len(clf.feature_importance) == len(X.columns)
     assert not np.isnan(clf.feature_importance).all().all()
