@@ -1,6 +1,7 @@
 import numpy as np
 import pandas as pd
 import pytest
+import woodwork as ww
 
 from evalml.data_checks import (
     DataCheckMessageCode,
@@ -76,21 +77,21 @@ def test_highly_null_data_check_input_formats():
     # test empty pd.DataFrame
     assert highly_null_check.validate(pd.DataFrame()) == {"warnings": [], "errors": []}
 
-    #  test list
-    assert highly_null_check.validate([None, None, None, None, 5]) == {
+    #  test Woodwork
+    ww_input = ww.DataTable(pd.DataFrame([[None, None, None, None, 0], [None, None, None, "hi", 5]]))
+    assert highly_null_check.validate(ww_input) == {
         "warnings": [DataCheckWarning(message="Column '0' is 80.0% or more null",
                                       data_check_name=highly_null_data_check_name,
                                       message_code=DataCheckMessageCode.HIGHLY_NULL,
-                                      details={"column": 0}).to_dict()],
-        "errors": []
-    }
-
-    #  test pd.Series
-    assert highly_null_check.validate(pd.Series([None, None, None, None, 5])) == {
-        "warnings": [DataCheckWarning(message="Column '0' is 80.0% or more null",
+                                      details={"column": 0}).to_dict(),
+                     DataCheckWarning(message="Column '1' is 80.0% or more null",
                                       data_check_name=highly_null_data_check_name,
                                       message_code=DataCheckMessageCode.HIGHLY_NULL,
-                                      details={"column": 0}).to_dict()],
+                                      details={"column": 1}).to_dict(),
+                     DataCheckWarning(message="Column '2' is 80.0% or more null",
+                                      data_check_name=highly_null_data_check_name,
+                                      message_code=DataCheckMessageCode.HIGHLY_NULL,
+                                      details={"column": 2}).to_dict()],
         "errors": []
     }
 
