@@ -2,17 +2,17 @@ from unittest.mock import patch
 
 import pandas as pd
 import pytest
+import woodwork as ww
 
 
-@patch('evalml.pipelines.ClassificationPipeline._decode_targets')
-@patch('evalml.objectives.BinaryClassificationObjective.decision_function')
-@patch('evalml.pipelines.components.Estimator.predict_proba')
-@patch('evalml.pipelines.components.Estimator.predict')
+@patch('evalml.pipelines.ClassificationPipeline._decode_targets', return_value=[0, 1])
+@patch('evalml.objectives.BinaryClassificationObjective.decision_function', return_value=pd.Series([1, 0]))
+@patch('evalml.pipelines.components.Estimator.predict_proba', return_value=ww.DataTable(pd.DataFrame([[0.1, 0.2], [0.1, 0.2]])))
+@patch('evalml.pipelines.components.Estimator.predict', return_value=ww.DataColumn(pd.Series([1, 0])))
 def test_binary_classification_pipeline_predict(mock_predict, mock_predict_proba,
                                                 mock_obj_decision, mock_decode,
                                                 X_y_binary, dummy_binary_pipeline_class):
     mock_objs = [mock_decode, mock_predict]
-    mock_decode.return_value = [0, 1]
     X, y = X_y_binary
     binary_pipeline = dummy_binary_pipeline_class(parameters={"Logistic Regression Classifier": {"n_jobs": 1}})
     # test no objective passed and no custom threshold uses underlying estimator's predict method
@@ -30,7 +30,6 @@ def test_binary_classification_pipeline_predict(mock_predict, mock_predict_proba
 
     mock_objs = [mock_decode, mock_predict_proba]
     # test custom threshold set but no objective passed
-    mock_predict_proba.return_value = pd.DataFrame([[0.1, 0.2], [0.1, 0.2]])
     binary_pipeline.threshold = 0.6
     binary_pipeline._encoder.classes_ = [0, 1]
     binary_pipeline.predict(X)
