@@ -3,18 +3,27 @@ from unittest.mock import patch
 import numpy as np
 import pandas as pd
 import pytest
+import woodwork as ww
+from pandas.testing import (
+    assert_frame_equal,
+    assert_index_equal,
+    assert_series_equal
+)
 
 from evalml.exceptions import MissingComponentError
 from evalml.pipelines import ComponentGraph
 from evalml.pipelines.components import (
+    DateTimeFeaturizer,
     ElasticNetClassifier,
     Estimator,
     Imputer,
     LogisticRegressionClassifier,
     OneHotEncoder,
     RandomForestClassifier,
+    StandardScaler,
     Transformer
 )
+from evalml.utils.gen_utils import infer_feature_types
 
 
 class DummyTransformer(Transformer):
@@ -339,8 +348,8 @@ def test_get_last_component(example_graph):
 @patch('evalml.pipelines.components.Estimator.predict')
 def test_fit(mock_predict, mock_fit, mock_fit_transform, example_graph, X_y_binary):
     X, y = X_y_binary
-    mock_fit_transform.return_value = pd.DataFrame(X)
-    mock_predict.return_value = pd.Series(y)
+    mock_fit_transform.return_value = ww.DataTable(X)
+    mock_predict.return_value = ww.DataColumn(y)
     component_graph = ComponentGraph(example_graph).instantiate({})
     component_graph.fit(X, y)
 
@@ -350,20 +359,21 @@ def test_fit(mock_predict, mock_fit, mock_fit_transform, example_graph, X_y_bina
 
 
 @patch('evalml.pipelines.components.Imputer.fit_transform')
-@patch('evalml.pipelines.components.OneHotEncoder.transform')
-def test_fit_correct_inputs(mock_transform, mock_fit_transform, X_y_binary):
+@patch('evalml.pipelines.components.OneHotEncoder.fit_transform')
+def test_fit_correct_inputs(mock_ohe_fit_transform, mock_imputer_fit_transform, X_y_binary):
     X, y = X_y_binary
     X = pd.DataFrame(X)
     y = pd.Series(y)
     graph = {'Imputer': [Imputer], 'OHE': [OneHotEncoder, 'Imputer.x', 'Imputer.y']}
-    expected_x = pd.DataFrame(index=X.index, columns=X.index).fillna(1)
-    expected_y = pd.Series(index=y.index).fillna(0)
-    mock_fit_transform.return_value = tuple((expected_x, expected_y))
+    expected_x = ww.DataTable(pd.DataFrame(index=X.index, columns=X.index).fillna(1))
+    expected_y = ww.DataColumn(pd.Series(index=y.index).fillna(0))
+    mock_imputer_fit_transform.return_value = tuple((expected_x, expected_y))
+    mock_ohe_fit_transform.return_value = expected_x
     component_graph = ComponentGraph(graph).instantiate({})
     component_graph.fit(X, y)
-
-    pd.testing.assert_frame_equal(mock_transform.call_args[0][0], expected_x)
-    pd.testing.assert_series_equal(mock_transform.call_args[0][1], expected_y)
+    expected_x_df = expected_x.to_dataframe().astype("Int64")
+    assert_frame_equal(expected_x_df, mock_ohe_fit_transform.call_args[0][0].to_dataframe())
+    assert_series_equal(expected_y.to_series(), mock_ohe_fit_transform.call_args[0][1].to_series())
 
 
 @patch('evalml.pipelines.components.Transformer.fit_transform')
@@ -375,10 +385,9 @@ def test_fit_features(mock_predict, mock_fit, mock_fit_transform, X_y_binary):
     component_graph = ComponentGraph.from_list(component_list)
     component_graph.instantiate({})
 
-    mock_X_t = pd.DataFrame(np.ones(pd.DataFrame(X).shape))
-    mock_fit_transform.return_value = mock_X_t
+    mock_fit_transform.return_value = ww.DataTable(np.ones(X.shape))
     mock_fit.return_value = Estimator
-    mock_predict.return_value = pd.Series(y)
+    mock_predict.return_value = ww.DataColumn(y)
 
     component_graph.fit_features(X, y)
 
@@ -395,10 +404,10 @@ def test_fit_features_nonlinear(mock_predict, mock_fit, mock_fit_transform, exam
     component_graph = ComponentGraph(example_graph)
     component_graph.instantiate({})
 
-    mock_X_t = pd.DataFrame(np.ones(pd.DataFrame(X).shape))
+    mock_X_t = ww.DataTable(np.ones(pd.DataFrame(X).shape))
     mock_fit_transform.return_value = mock_X_t
     mock_fit.return_value = Estimator
-    mock_predict.return_value = pd.Series(y)
+    mock_predict.return_value = ww.DataColumn(pd.Series(y))
 
     component_graph.fit_features(X, y)
 
@@ -411,7 +420,7 @@ def test_fit_features_nonlinear(mock_predict, mock_fit, mock_fit_transform, exam
 @patch('evalml.pipelines.components.Estimator.predict')
 def test_predict(mock_predict, mock_fit, example_graph, X_y_binary):
     X, y = X_y_binary
-    mock_predict.return_value = pd.Series(y)
+    mock_predict.return_value = ww.DataColumn(pd.Series(y))
     component_graph = ComponentGraph(example_graph).instantiate({})
     component_graph.fit(X, y)
 
@@ -424,7 +433,7 @@ def test_predict(mock_predict, mock_fit, example_graph, X_y_binary):
 @patch('evalml.pipelines.components.Estimator.predict')
 def test_predict_repeat_estimator(mock_predict, mock_fit, X_y_binary):
     X, y = X_y_binary
-    mock_predict.return_value = pd.Series(y)
+    mock_predict.return_value = ww.DataColumn(pd.Series(y))
 
     graph = {'Imputer': [Imputer],
              'OneHot_RandomForest': [OneHotEncoder, 'Imputer.x'],
@@ -448,9 +457,9 @@ def test_predict_repeat_estimator(mock_predict, mock_fit, X_y_binary):
 def test_compute_final_component_features_linear(mock_ohe, mock_imputer, X_y_binary):
     X, y = X_y_binary
     X = pd.DataFrame(X)
-    X_expected = pd.DataFrame(index=X.index, columns=X.columns).fillna(0)
-    mock_imputer.return_value = X
-    mock_ohe.return_value = X_expected
+    X_expected = X.fillna(0)
+    mock_imputer.return_value = ww.DataTable(X)
+    mock_ohe.return_value = ww.DataTable(X_expected)
 
     component_list = ['Imputer', 'One Hot Encoder', 'Random Forest Classifier']
     component_graph = ComponentGraph().from_list(component_list)
@@ -458,7 +467,7 @@ def test_compute_final_component_features_linear(mock_ohe, mock_imputer, X_y_bin
     component_graph.fit(X, y)
 
     X_t = component_graph.compute_final_component_features(X)
-    pd.testing.assert_frame_equal(X_t, X_expected)
+    assert_frame_equal(X_expected, X_t.to_dataframe())
     assert mock_imputer.call_count == 2
     assert mock_ohe.call_count == 2
 
@@ -469,16 +478,16 @@ def test_compute_final_component_features_linear(mock_ohe, mock_imputer, X_y_bin
 @patch('evalml.pipelines.components.ElasticNetClassifier.predict')
 def test_compute_final_component_features_nonlinear(mock_en_predict, mock_rf_predict, mock_ohe, mock_imputer, example_graph, X_y_binary):
     X, y = X_y_binary
-    mock_imputer.return_value = pd.DataFrame(X)
-    mock_ohe.return_value = pd.DataFrame(X)
-    mock_en_predict.return_value = pd.Series(np.ones(X.shape[0]))
-    mock_rf_predict.return_value = pd.Series(np.zeros(X.shape[0]))
+    mock_imputer.return_value = ww.DataTable(pd.DataFrame(X))
+    mock_ohe.return_value = ww.DataTable(pd.DataFrame(X))
+    mock_en_predict.return_value = ww.DataColumn(pd.Series(np.ones(X.shape[0])))
+    mock_rf_predict.return_value = ww.DataColumn(pd.Series(np.zeros(X.shape[0])))
     X_expected = pd.DataFrame({'Random Forest': np.zeros(X.shape[0]), 'Elastic Net': np.ones(X.shape[0])})
     component_graph = ComponentGraph(example_graph).instantiate({})
     component_graph.fit(X, y)
 
     X_t = component_graph.compute_final_component_features(X)
-    pd.testing.assert_frame_equal(X_t, X_expected)
+    assert_frame_equal(X_expected, X_t.to_dataframe())
     assert mock_imputer.call_count == 2
     assert mock_ohe.call_count == 4
 
@@ -487,12 +496,12 @@ def test_compute_final_component_features_nonlinear(mock_en_predict, mock_rf_pre
 def test_compute_final_component_features_single_component(mock_transform, X_y_binary):
     X, y = X_y_binary
     X = pd.DataFrame(X)
-    mock_transform.return_value = pd.DataFrame()
+    mock_transform.return_value = ww.DataTable(X)
     component_graph = ComponentGraph({'Dummy Component': [DummyTransformer]}).instantiate({})
     component_graph.fit(X, y)
 
     X_t = component_graph.compute_final_component_features(X)
-    pd.testing.assert_frame_equal(X_t, X)
+    assert_frame_equal(X, X_t.to_dataframe())
 
 
 @patch('evalml.pipelines.components.Imputer.fit_transform')
@@ -516,7 +525,7 @@ def test_predict_empty_graph(X_y_binary):
 
     component_graph.fit(X, y)
     X_t = component_graph.predict(X)
-    pd.testing.assert_frame_equal(X_t, X)
+    assert_frame_equal(X, X_t.to_dataframe())
 
 
 @patch('evalml.pipelines.components.OneHotEncoder.fit_transform')
@@ -530,8 +539,7 @@ def test_predict_transformer_end(mock_fit_transform, mock_transform, X_y_binary)
 
     component_graph.fit(X, y)
     output = component_graph.predict(X)
-
-    pd.testing.assert_frame_equal(output, pd.DataFrame(X))
+    assert_frame_equal(pd.DataFrame(X), output.to_dataframe())
 
 
 def test_no_instantiate_before_fit(X_y_binary):
@@ -584,8 +592,8 @@ def test_computation_input_custom_index(index):
     component_graph.instantiate({})
     component_graph.fit(X, y)
 
-    X_t = component_graph.predict(X)
-    pd.testing.assert_index_equal(X_t.index, pd.RangeIndex(start=0, stop=5, step=1))
+    X_t = component_graph.predict(X).to_series()
+    assert_index_equal(X_t.index, pd.RangeIndex(start=0, stop=5, step=1))
     assert not X_t.isna().any(axis=None)
 
 
@@ -597,12 +605,12 @@ def test_computation_input_custom_index(index):
 @patch(f'{__name__}.TransformerA.transform')
 def test_component_graph_evaluation_plumbing(mock_transa, mock_transb, mock_transc, mock_preda, mock_predb, mock_predc, dummy_components):
     TransformerA, TransformerB, TransformerC, EstimatorA, EstimatorB, EstimatorC = dummy_components
-    mock_transa.return_value = pd.DataFrame({'feature trans': [1, 0, 0, 0, 0, 0], 'feature a': np.ones(6)})
-    mock_transb.return_value = pd.DataFrame({'feature b': np.ones(6) * 2})
-    mock_transc.return_value = pd.DataFrame({'feature c': np.ones(6) * 3})
-    mock_preda.return_value = pd.Series([0, 0, 0, 1, 0, 0])
-    mock_predb.return_value = pd.Series([0, 0, 0, 0, 1, 0])
-    mock_predc.return_value = pd.Series([0, 0, 0, 0, 0, 1])
+    mock_transa.return_value = ww.DataTable(pd.DataFrame({'feature trans': [1, 0, 0, 0, 0, 0], 'feature a': np.ones(6)}))
+    mock_transb.return_value = ww.DataTable(pd.DataFrame({'feature b': np.ones(6) * 2}))
+    mock_transc.return_value = ww.DataTable(pd.DataFrame({'feature c': np.ones(6) * 3}))
+    mock_preda.return_value = ww.DataColumn(pd.Series([0, 0, 0, 1, 0, 0]))
+    mock_predb.return_value = ww.DataColumn(pd.Series([0, 0, 0, 0, 1, 0]))
+    mock_predc.return_value = ww.DataColumn(pd.Series([0, 0, 0, 0, 0, 1]))
     graph = {
         'transformer a': [TransformerA],
         'transformer b': [TransformerB, 'transformer a'],
@@ -618,13 +626,25 @@ def test_component_graph_evaluation_plumbing(mock_transa, mock_transb, mock_tran
     component_graph.fit(X, y)
     predict_out = component_graph.predict(X)
 
-    pd.testing.assert_frame_equal(mock_transa.call_args[0][0], X)
-    pd.testing.assert_frame_equal(mock_transb.call_args[0][0], pd.DataFrame({'feature trans': [1, 0, 0, 0, 0, 0], 'feature a': np.ones(6)}, columns=['feature trans', 'feature a']))
-    pd.testing.assert_frame_equal(mock_transc.call_args[0][0], pd.DataFrame({'feature trans': [1, 0, 0, 0, 0, 0], 'feature a': np.ones(6), 'feature b': np.ones(6) * 2}, columns=['feature trans', 'feature a', 'feature b']))
-    pd.testing.assert_frame_equal(mock_preda.call_args[0][0], X)
-    pd.testing.assert_frame_equal(mock_predb.call_args[0][0], pd.DataFrame({'feature trans': [1, 0, 0, 0, 0, 0], 'feature a': np.ones(6)}, columns=['feature trans', 'feature a']))
-    pd.testing.assert_frame_equal(mock_predc.call_args[0][0], pd.DataFrame({'feature trans': [1, 0, 0, 0, 0, 0], 'feature a': np.ones(6), 'estimator a': [0, 0, 0, 1, 0, 0], 'feature b': np.ones(6) * 2, 'estimator b': [0, 0, 0, 0, 1, 0], 'feature c': np.ones(6) * 3}, columns=['feature trans', 'feature a', 'estimator a', 'feature b', 'estimator b', 'feature c']))
-    pd.testing.assert_series_equal(predict_out, pd.Series([0, 0, 0, 0, 0, 1]))
+    assert_frame_equal(mock_transa.call_args[0][0].to_dataframe(), X)
+    assert_frame_equal(mock_transb.call_args[0][0].to_dataframe(), pd.DataFrame({'feature trans': pd.Series([1, 0, 0, 0, 0, 0], dtype="Int64"),
+                                                                                 'feature a': np.ones(6)}, columns=['feature trans', 'feature a']))
+    assert_frame_equal(mock_transc.call_args[0][0].to_dataframe(), pd.DataFrame({'feature trans': pd.Series([1, 0, 0, 0, 0, 0], dtype="Int64"),
+                                                                                 'feature a': np.ones(6),
+                                                                                 'feature b': np.ones(6) * 2},
+                                                                                columns=['feature trans', 'feature a', 'feature b']))
+    assert_frame_equal(mock_preda.call_args[0][0].to_dataframe(), X)
+    assert_frame_equal(mock_predb.call_args[0][0].to_dataframe(), pd.DataFrame({'feature trans': pd.Series([1, 0, 0, 0, 0, 0], dtype="Int64"),
+                                                                                'feature a': np.ones(6)},
+                                                                               columns=['feature trans', 'feature a']))
+    assert_frame_equal(mock_predc.call_args[0][0].to_dataframe(), pd.DataFrame({'feature trans': pd.Series([1, 0, 0, 0, 0, 0], dtype="Int64"),
+                                                                                'feature a': np.ones(6),
+                                                                                'estimator a': pd.Series([0, 0, 0, 1, 0, 0], dtype="Int64"),
+                                                                                'feature b': np.ones(6) * 2,
+                                                                                'estimator b': pd.Series([0, 0, 0, 0, 1, 0], dtype="Int64"),
+                                                                                'feature c': np.ones(6) * 3},
+                                                                               columns=['feature trans', 'feature a', 'estimator a', 'feature b', 'estimator b', 'feature c']))
+    assert_series_equal(pd.Series([0, 0, 0, 0, 0, 1], dtype="Int64"), predict_out.to_series())
 
 
 def test_input_feature_names(example_graph):
@@ -658,3 +678,61 @@ def test_iteration(example_graph):
     expected = [Imputer(), OneHotEncoder(), ElasticNetClassifier(), OneHotEncoder(top_n=32), RandomForestClassifier(), LogisticRegressionClassifier()]
     iteration = [component for component in component_graph]
     assert iteration == expected
+
+
+def test_custom_input_feature_types(example_graph):
+    X = pd.DataFrame({'column_1': ['a', 'b', 'c', 'd', 'a', 'a', 'b', 'c', 'b'],
+                      'column_2': [1, 2, 3, 4, 5, 6, 5, 4, 3]})
+    y = pd.Series([1, 0, 1, 0, 1, 1, 0, 0, 0])
+    X = infer_feature_types(X, {"column_2": "categorical"})
+
+    component_graph = ComponentGraph(example_graph)
+    component_graph.instantiate({'OneHot_RandomForest': {'top_n': 2},
+                                 'OneHot_ElasticNet': {'top_n': 3}})
+    assert component_graph.input_feature_names == {}
+    component_graph.fit(X, y)
+
+    input_feature_names = component_graph.input_feature_names
+    assert input_feature_names['Imputer'] == ['column_1', 'column_2']
+    assert input_feature_names['OneHot_RandomForest'] == ['column_1', 'column_2']
+    assert input_feature_names['OneHot_ElasticNet'] == ['column_1', 'column_2']
+    assert input_feature_names['Random Forest'] == ['column_1_a', 'column_1_b', 'column_2_3', 'column_2_4']
+    assert input_feature_names['Elastic Net'] == ['column_1_a', 'column_1_b', 'column_1_c', 'column_2_3', 'column_2_4', 'column_2_5']
+    assert input_feature_names['Logistic Regression'] == ['Random Forest', 'Elastic Net']
+
+
+def test_component_graph_dataset_with_different_types():
+    # Checks that types are converted correctly by Woodwork. Specifically, the standard scaler
+    # should convert column_3 to float, so our code to try to convert back to the original boolean type
+    # will catch the TypeError thrown and not convert the column.
+    graph = {'Imputer': [Imputer],
+             'OneHot': [OneHotEncoder, 'Imputer.x'],
+             'DateTime': [DateTimeFeaturizer, 'OneHot.x'],
+             'Scaler': [StandardScaler, 'DateTime.x'],
+             'Random Forest': [RandomForestClassifier, 'Scaler.x'],
+             'Elastic Net': [ElasticNetClassifier, 'Scaler.x'],
+             'Logistic Regression': [LogisticRegressionClassifier, 'Random Forest', 'Elastic Net']}
+
+    X = pd.DataFrame({'column_1': ['a', 'b', 'c', 'd', 'a', 'a', 'b', 'c', 'b'],
+                      'column_2': [1, 2, 3, 4, 5, 6, 5, 4, 3],
+                      'column_3': [True, False, True, False, True, False, True, False, False]})
+    y = pd.Series([1, 0, 1, 0, 1, 1, 0, 0, 0])
+    X = infer_feature_types(X, {"column_2": "categorical"})
+
+    component_graph = ComponentGraph(graph)
+    component_graph.instantiate({})
+    assert component_graph.input_feature_names == {}
+    component_graph.fit(X, y)
+
+    input_feature_names = component_graph.input_feature_names
+    assert input_feature_names['Imputer'] == ['column_1', 'column_2', 'column_3']
+    assert input_feature_names['OneHot'] == ['column_1', 'column_2', 'column_3']
+    assert input_feature_names['DateTime'] == ['column_3', 'column_1_a', 'column_1_b', 'column_1_c', 'column_1_d',
+                                               'column_2_1', 'column_2_2', 'column_2_3', 'column_2_4', 'column_2_5', 'column_2_6']
+    assert input_feature_names['Scaler'] == ['column_3', 'column_1_a', 'column_1_b', 'column_1_c', 'column_1_d',
+                                             'column_2_1', 'column_2_2', 'column_2_3', 'column_2_4', 'column_2_5', 'column_2_6']
+    assert input_feature_names['Random Forest'] == ['column_3', 'column_1_a', 'column_1_b', 'column_1_c', 'column_1_d',
+                                                    'column_2_1', 'column_2_2', 'column_2_3', 'column_2_4', 'column_2_5', 'column_2_6']
+    assert input_feature_names['Elastic Net'] == ['column_3', 'column_1_a', 'column_1_b', 'column_1_c', 'column_1_d',
+                                                  'column_2_1', 'column_2_2', 'column_2_3', 'column_2_4', 'column_2_5', 'column_2_6']
+    assert input_feature_names['Logistic Regression'] == ['Random Forest', 'Elastic Net']
