@@ -14,13 +14,11 @@ from evalml.utils.gen_utils import (
     _convert_to_woodwork_structure,
     _convert_woodwork_types_wrapper,
     _rename_column_names_to_numeric,
-    check_random_state_equality,
     classproperty,
     convert_to_seconds,
     drop_rows_with_nans,
     get_importable_subclasses,
     get_random_seed,
-    get_random_state,
     import_or_raise,
     infer_feature_types,
     jupyter_check,
@@ -72,20 +70,6 @@ def test_convert_to_seconds():
         convert_to_seconds("10 years")
 
 
-def test_get_random_state_int():
-    assert abs(get_random_state(None).rand() - get_random_state(None).rand()) > 1e-6
-    assert get_random_state(42).rand() == np.random.RandomState(42).rand()
-    assert get_random_state(np.random.RandomState(42)).rand() == np.random.RandomState(42).rand()
-    assert get_random_state(SEED_BOUNDS.min_bound).rand() == np.random.RandomState(SEED_BOUNDS.min_bound).rand()
-    assert get_random_state(SEED_BOUNDS.max_bound).rand() == np.random.RandomState(SEED_BOUNDS.max_bound).rand()
-    with pytest.raises(ValueError, match=r'Seed "[-0-9]+" is not in the range \[{}, {}\], inclusive'.format(
-            SEED_BOUNDS.min_bound, SEED_BOUNDS.max_bound)):
-        get_random_state(SEED_BOUNDS.min_bound - 1)
-    with pytest.raises(ValueError, match=r'Seed "[-0-9]+" is not in the range \[{}, {}\], inclusive'.format(
-            SEED_BOUNDS.min_bound, SEED_BOUNDS.max_bound)):
-        get_random_state(SEED_BOUNDS.max_bound + 1)
-
-
 def test_get_random_seed_rng():
 
     def make_mock_random_state(return_value):
@@ -205,29 +189,6 @@ def test_import_or_warn_errors(dummy_importlib):
         import_or_raise("attr_error_lib", warning=True)
 
 
-def test_check_random_state_equality():
-    assert check_random_state_equality(get_random_state(1), get_random_state(1))
-
-    rs_1 = get_random_state(1)
-    rs_2 = get_random_state(2)
-    assert not check_random_state_equality(rs_1, rs_2)
-
-    # Test equality
-    rs_1.set_state(tuple(['MT19937', np.array([1] * 624), 0, 1, 0.1]))
-    rs_2.set_state(tuple(['MT19937', np.array([1] * 624), 0, 1, 0.1]))
-    assert check_random_state_equality(rs_1, rs_2)
-
-    # Test numpy array value not equal
-    rs_1.set_state(tuple(['MT19937', np.array([0] * 624), 0, 1, 0.1]))
-    rs_2.set_state(tuple(['MT19937', np.array([1] * 624), 1, 1, 0.1]))
-    assert not check_random_state_equality(rs_1, rs_2)
-
-    # Test non-numpy array value not equal
-    rs_1.set_state(tuple(['MT19937', np.array([1] * 624), 0, 1, 0.1]))
-    rs_2.set_state(tuple(['MT19937', np.array([1] * 624), 1, 1, 0.1]))
-    assert not check_random_state_equality(rs_1, rs_2)
-
-
 @patch('evalml.utils.gen_utils.import_or_raise')
 def test_jupyter_check_errors(mock_import_or_raise):
     mock_import_or_raise.side_effect = ImportError
@@ -271,6 +232,13 @@ def test_pad_with_nans(data, num_to_pad, expected):
     _check_equality(padded, expected)
 
 
+def test_pad_with_nans_with_series_name():
+    name = "data to pad"
+    data = pd.Series([1, 2, 3], name=name)
+    padded = pad_with_nans(data, 1)
+    _check_equality(padded, pd.Series([np.nan, 1, 2, 3], name=name))
+
+
 @pytest.mark.parametrize("data, expected",
                          [([pd.Series([None, 1., 2., 3]), pd.DataFrame({"a": [1., 2., 3, None]})],
                            [pd.Series([1., 2.], index=pd.Int64Index([1, 2])),
@@ -278,6 +246,10 @@ def test_pad_with_nans(data, num_to_pad, expected):
                           ([pd.Series([None, 1., 2., 3]), pd.DataFrame({"a": [3., 4., None, None]})],
                            [pd.Series([1.], index=pd.Int64Index([1])),
                             pd.DataFrame({"a": [4.]}, index=pd.Int64Index([1]))]),
+                          ([pd.DataFrame(), pd.Series([None, 1., 2., 3.])],
+                           [pd.DataFrame(), pd.Series([1., 2., 3.], index=pd.Int64Index([1, 2, 3]))]),
+                          ([pd.DataFrame({"a": [1., 2., None]}), pd.Series([])],
+                           [pd.DataFrame({"a": [1., 2.]}), pd.Series([])])
                           ])
 def test_drop_nan(data, expected):
     no_nan_1, no_nan_2 = drop_rows_with_nans(*data)
@@ -339,6 +311,13 @@ def test_convert_woodwork_types_wrapper():
     pd.testing.assert_series_equal(y, pd.Series([True, False, True], dtype="bool"))
 
 
+def test_convert_woodwork_types_wrapper_series_name():
+    name = "my series name"
+    series_with_name = pd.Series([1, 2, 3], name=name)
+    y = _convert_woodwork_types_wrapper(series_with_name)
+    assert y.name == name
+
+
 def test_convert_woodwork_types_wrapper_dataframe():
     X = pd.DataFrame({"Int series": pd.Series([1, 2, 3], dtype="Int64"),
                       "Int array": pd.array([1, 2, 3], dtype="Int64"),
@@ -399,6 +378,14 @@ def test_convert_to_woodwork_structure():
     assert np.array_equal(X_np, np.array([[1, 2], [3, 4]]))
 
 
+def test_convert_to_woodwork_structure_series_name():
+    name = "column with name"
+    X_pd = pd.Series([1, 2, 3, 4], dtype="Int64", name=name)
+    X_dc = _convert_to_woodwork_structure(X_pd)
+    assert X_dc.name == name
+    pd.testing.assert_series_equal(X_pd, X_dc.to_series())
+
+
 def test_infer_feature_types_dataframe():
     X_pd = pd.DataFrame({0: pd.Series([1, 2]),
                          1: pd.Series([3, 4])})
