@@ -4,7 +4,6 @@ from .gen_utils import (
     import_or_raise,
     convert_to_seconds,
     get_random_state,
-    check_random_state_equality,
     get_random_seed,
     SEED_BOUNDS,
     jupyter_check,
@@ -14,6 +13,7 @@ from .gen_utils import (
     drop_rows_with_nans,
     pad_with_nans,
     infer_feature_types,
-    _get_rows_without_nans
+    _get_rows_without_nans,
+    save_plot
 )
 from .cli_utils import print_info, get_evalml_root, get_installed_packages, get_sys_info, print_sys_info, print_deps
