@@ -17,11 +17,7 @@ from evalml.utils import get_logger
 
 logger = get_logger(__file__)
 
-numeric_dtypes = ['int16', 'int32', 'int64', 'float16', 'float32', 'float64']
-boolean = ['bool']
-numeric_and_boolean_dtypes = numeric_dtypes + boolean
-categorical_dtypes = ['object', 'category']
-datetime_dtypes = [np.datetime64]
+numeric_and_boolean_ww = [ww.logical_types.Integer, ww.logical_types.Double, ww.logical_types.Boolean]
 
 
 def import_or_raise(library, error_msg=None, warning=False):
@@ -109,18 +105,6 @@ def get_random_seed(random_state, min_bound=SEED_BOUNDS.min_bound, max_bound=SEE
     return random_state
 
 
-def check_random_state_equality(random_state, other_random_state):
-    """Method to check for equality of two numpy.random.RandomState objects"""
-    for self_rs_attr, other_rs_attr in zip(random_state.get_state(), other_random_state.get_state()):
-        if isinstance(self_rs_attr, np.ndarray) and isinstance(other_rs_attr, np.ndarray):
-            if not (self_rs_attr == other_rs_attr).all():
-                return False
-        else:
-            if not (self_rs_attr == other_rs_attr):
-                return False
-    return True
-
-
 class classproperty:
     """Allows function to be accessed as a class level property.
         Example:
@@ -171,11 +155,13 @@ def _get_subclasses(base_class):
     return subclasses
 
 
-_not_used_in_automl = {'BaselineClassifier', 'BaselineRegressor', 'TimeSeriesBaselineRegressor',
+_not_used_in_automl = {'BaselineClassifier', 'BaselineRegressor', 'TimeSeriesBaselineEstimator',
                        'StackedEnsembleClassifier', 'StackedEnsembleRegressor',
                        'ModeBaselineBinaryPipeline', 'BaselineBinaryPipeline', 'MeanBaselineRegressionPipeline',
                        'BaselineRegressionPipeline', 'ModeBaselineMulticlassPipeline', 'BaselineMulticlassPipeline',
-                       'TimeSeriesBaselineRegressionPipeline'}
+                       'TimeSeriesBaselineRegressionPipeline', 'TimeSeriesBaselineBinaryPipeline',
+                       'TimeSeriesBaselineMulticlassPipeline', 'KNeighborsClassifier',
+                       'SVMClassifier', 'SVMRegressor'}
 
 
 def get_importable_subclasses(base_class, used_in_automl=True):
@@ -223,7 +209,7 @@ def _rename_column_names_to_numeric(X):
         Transformed X where column names are renamed to numerical values
     """
     X_t = X
-    if isinstance(X, np.ndarray):
+    if isinstance(X, (np.ndarray, list)):
         return pd.DataFrame(X)
     if isinstance(X, ww.DataTable):
         X_t = X.to_dataframe()
@@ -269,20 +255,21 @@ def safe_repr(value):
     return repr(value)
 
 
-def is_all_numeric(df):
-    """Checks if the given DataFrame contains only numeric values
+def is_all_numeric(dt):
+    """Checks if the given DataTable contains only numeric values
 
     Arguments:
-        df (DataFrame): The DataFrame to check datatypes of
+        dt (ww.DataTable): The DataTable to check data types of.
 
     Returns:
-        True if all the DataFrame columns are numeric and are not missing any values, False otherwise
+        True if all the DataTable columns are numeric and are not missing any values, False otherwise.
     """
-    if df.isnull().any().any():
-        return False
-    for dtype in df.dtypes:
-        if dtype not in numeric_and_boolean_dtypes:
+    for col_tags in dt.semantic_tags.values():
+        if "numeric" not in col_tags:
             return False
+
+    if dt.to_dataframe().isnull().any().any():
+        return False
     return True
 
 
@@ -320,7 +307,8 @@ def _convert_to_woodwork_structure(data):
 
     ww_data = ww_data.copy()
     if len(ww_data.shape) == 1:
-        return ww.DataColumn(ww_data)
+        name = ww_data.name if isinstance(ww_data, pd.Series) else None
+        return ww.DataColumn(ww_data, name=name)
     return ww.DataTable(ww_data)
 
 
@@ -347,8 +335,8 @@ def _convert_woodwork_types_wrapper(pd_data):
         return pd.Series(pd_data.to_numpy(na_value=np.nan), dtype=nullable_to_numpy_mapping[type(pd_data.dtype)])
     if (isinstance(pd_data, pd.Series) and type(pd_data.dtype) in nullable_to_numpy_mapping):
         if pd.isna(pd_data).any():
-            return pd.Series(pd_data.to_numpy(na_value=np.nan), dtype=nullable_to_numpy_mapping_nan[type(pd_data.dtype)], index=pd_data.index)
-        return pd.Series(pd_data.to_numpy(na_value=np.nan), dtype=nullable_to_numpy_mapping[type(pd_data.dtype)], index=pd_data.index)
+            return pd.Series(pd_data.to_numpy(na_value=np.nan), dtype=nullable_to_numpy_mapping_nan[type(pd_data.dtype)], index=pd_data.index, name=pd_data.name)
+        return pd.Series(pd_data.to_numpy(na_value=np.nan), dtype=nullable_to_numpy_mapping[type(pd_data.dtype)], index=pd_data.index, name=pd_data.name)
     if isinstance(pd_data, pd.DataFrame):
         for col_name, col in pd_data.iteritems():
             if type(col.dtype) in nullable_to_numpy_mapping:
@@ -369,7 +357,7 @@ def pad_with_nans(pd_data, num_to_pad):
         pd.DataFrame or pd.Series
     """
     if isinstance(pd_data, pd.Series):
-        padding = pd.Series([np.nan] * num_to_pad)
+        padding = pd.Series([np.nan] * num_to_pad, name=pd_data.name)
     else:
         padding = pd.DataFrame({col: [np.nan] * num_to_pad
                                 for col in pd_data.columns})
@@ -391,7 +379,7 @@ def _get_rows_without_nans(*data):
             are non-nan.
     """
     def _not_nan(pd_data):
-        if pd_data is None:
+        if pd_data is None or len(pd_data) == 0:
             return np.array([True])
         if isinstance(pd_data, pd.Series):
             return ~pd_data.isna().values
@@ -404,19 +392,24 @@ def _get_rows_without_nans(*data):
     return mask
 
 
-def drop_rows_with_nans(pd_data_1, pd_data_2):
-    """Drop rows that have any NaNs in both pd_data_1 and pd_data_2.
+def drop_rows_with_nans(*pd_data):
+    """Drop rows that have any NaNs in all dataframes or series.
 
     Arguments:
-        pd_data_1 (pd.DataFrame or pd.Series): Data to subset.
-        pd_data_2 (pd.DataFrame or pd.Series): Data to subset.
+        *pd_data (sequence of pd.Series or pd.DataFrame or None)
 
     Returns:
-        tuple of pd.DataFrame or pd.Series
+        list of pd.DataFrame or pd.Series or None
     """
 
-    mask = _get_rows_without_nans(pd_data_1, pd_data_2)
-    return pd_data_1.iloc[mask], pd_data_2.iloc[mask]
+    mask = _get_rows_without_nans(*pd_data)
+
+    def _subset(pd_data):
+        if pd_data is not None and not pd_data.empty:
+            return pd_data.iloc[mask]
+        return pd_data
+
+    return [_subset(data) for data in pd_data]
 
 
 def _file_path_check(filepath=None, format='png', interactive=False, is_plotly=False):
